/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.common.converter;

import java.util.Locale;
import java.util.StringTokenizer;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.ConverterException;
import cookxml.core.interfaces.Converter;

/**
 * Convert a string into locale.
 *
 * @cxdoc
 * The format is "lang_country_variant".  For example, "en_US".
 *
 * @see java.util.Locale
 * @author Heng Yuan
 * @version $Id: LocaleConverter.java 230 2007-06-06 07:12:56Z coconut $
 * @since CookXml 1.0
 */
public class LocaleConverter implements Converter
{
	private final static LocaleConverter s_instance = new LocaleConverter ();

	public static LocaleConverter getInstance ()
	{
		return s_instance;
	}

	private LocaleConverter ()
	{
	}

	public Object convert (String value, DecodeEngine decodeEngine) throws ConverterException
	{
		try
		{
			StringTokenizer tokenizer = new StringTokenizer (value, "_ ");
			String lang = tokenizer.nextToken ();
			String country = "";
			String variant = "";
			if (tokenizer.hasMoreTokens ())
			{
				country = tokenizer.nextToken ();
				if (tokenizer.hasMoreTokens ())
					variant = tokenizer.nextToken ();
			}
			return new Locale (lang, country, variant);
		}
		catch (Exception ex)
		{
			throw new ConverterException (decodeEngine, ex, this, value);
		}
	}
}
