/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.common.creator;

import org.w3c.dom.Comment;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Creator;

/**
 * This creator take the first comment node of inside this html element to be the data
 * to be returned.  The main reason to use element is to enter html texts that contain
 * tags as well.  The results returned is still a string text however.  For this reason,
 * to load a html resource, use the {@link TextCreator}.
 *
 * @cxdoc
 * This tag takes the text inside the first node (must be a comment node) and use
 * it as the text string object.  This tag allows input of XML type of text
 * easily.  Of course, you could choose to use &lt;![CDATA[ text... ]]> inside
 * {@tag text} tag to input such text, but it is fairly difficult to remember the
 * syntax.
 *
 * @cxexample
 * <codeblock type="xml">
 *     <html><!--<span style="color: gray">text</span>--></html>
 *     <html><!--<span style="color: gray"><html><body><p>html text</p></body></html></span>--></html>
 * </codeblock>
 *
 * @see java.lang.String
 * @author Heng Yuan
 * @version $Id: HtmlCreator.java 248 2007-06-07 06:57:32Z coconut $
 * @since CookXml 1.0
 */
public class HtmlCreator implements Creator
{
	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine)
	{
		decodeEngine.setDoProcessChildren (false);
		Node node = elm.getFirstChild ();
		if (node != null && node instanceof Comment)
			return ((Comment)node).getData ();
		return null;
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine)
	{
		return obj;
	}
}
