/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.common.helper;

/**
 * Helper class for constructing a MapEntry object.
 *
 * @cxdoc
 * This tag is needed to create an entry in the parent {@tag map} container.
 * 
 * @cxexample
 * <codeblock>
 * 	<hashmap>
 * 		<mapentry key="today" value="great"/>	<!-- a map entry with a String as the key -->
 * 		<mapentry value="great">		<!-- a map entry with an Integer as the key -->
 * 			<int value="1" setas="key">	<!-- "setas" is a global attribute defined in namespace http://cookxml.sf.net/ -->
 * 		<mapentry>
 * 	</hashmap>
 * </codeblock>
 *
 * @author Heng Yuan
 * @version $Id: MapEntryHelper.java 252 2007-06-08 00:22:54Z coconut $
 * @since CookXml 1.0
 */
public class MapEntryHelper
{
	/** the key for the map entry */
	public Object key;
	/** the value for the map entry */
	public Object value;

    /**
     * an alternative name for the key.
     * @param   attr
     *          the attribute name
     */
	public void setAttribute (Object attr)
	{
		key = attr;
	}

	/**
	 * an alternative name for the key.
	 * @param   attr
	 *          the attribute name
	 */
	public void setAttr (Object attr)
	{
		key = attr;
	}
}
