/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookbsf;

import org.apache.bsf.BSFManager;
import org.apache.bsf.util.ObjectRegistry;
import org.w3c.dom.Attr;
import org.w3c.dom.CharacterData;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Creator;
import cookxml.core.util.TextUtils;

/**
 * This class creates a BSFManager instance and use it to load the appropriate script engine and interpret
 * code within the tag.
 *
 * @author Heng Yuan
 * @version $Id: BSFCreator.java 231 2007-06-06 07:14:28Z coconut $
 * @since CookBSF 1.0
 */
class BSFCreator implements Creator
{
	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine) throws Exception
	{
		decodeEngine.setDoAdd (false);

		String src = elm.getAttribute (CookBSFLib.SRC_ATTR);
		String code;

		if (src.length () == 0)
		{
			Node node = elm.getFirstChild ();
			if (node == null || (!(node instanceof CharacterData)))
				return null;
			src = null;
			code = ((CharacterData)node).getData ();
		}
		else
		{
			code  = TextUtils.readText (src, decodeEngine.getCookXml ().getClassLoader ());
			if (code == null)
				return null;
		}

		String lang = elm.getAttribute (CookBSFLib.LANG_ATTR).trim ();
		if (lang.length () == 0 && src != null)
		{
			lang = BSFManager.getLangFromFilename (src);
		}
		// test again
		if (lang == null || lang.length () == 0)
			throw new IllegalArgumentException ("unknown script language");

		Attr returnAttr = elm.getAttributeNode (CookBSFLib.RETURN_ATTR);

		BSFManager bsfManager = new BSFManager ();
		ObjectRegistry reg = new ObjectRegistry (new CookXmlObjectRegistry (decodeEngine.getCookXml ()));
		bsfManager.setObjectRegistry (reg);

		if (returnAttr == null)
			return bsfManager.eval (lang, src, 1, 1, code);
		else
		{
			bsfManager.exec (lang, src, 1, 1, code);
			String returnVar = returnAttr.getValue ().trim ();
			if (returnVar.length () > 0)
				return bsfManager.getObjectRegistry ().lookup (returnVar);
			return null;
		}
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine)
	{
		decodeEngine.addChild (parentNS, parentTag, elm, parentObj, obj);
		return obj;
	}
}
