/*
 * (c) Copyright 2005-2007 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookbsf;

import cookxml.core.setter.DoNothingSetter;
import cookxml.core.taglibrary.InheritableTagLibrary;

/**
 * This is the BSF (Bean Scripting Framework http://jakarta.apache.org/bsf/) extension for CookXml.
 * <p>
 * Currently, it supports three attributes:
 * <ul>
 * <li>language="language", must be specified or able to be determined from the source file extension
 * <li>src="uri for the external script", useful when you want to load source code from a resource.
 *		Also, the language may be determined from the file extension.
 * <li>return="variable", optional, only for languages that does not a way to return a value from the
 *		script (e.g. Jython).
 * </ul>
 *
 * @author Heng Yuan
 * @version $Id: CookBSFLib.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookBSF 1.0
 */
public class CookBSFLib
{
	public static String BSF_TAG = "script";
	public static String SRC_ATTR = "src";
	public static String LANG_ATTR = "language";
	public static String RETURN_ATTR = "return";

	/**
	 * Adds &lt;script> tag to the tag library specified.
	 *
	 * @param	tagLibrary
	 * 			the tag library to be setup
	 * @since	CookBSF 1.0
	 */
	public static void setupTags (InheritableTagLibrary tagLibrary)
	{
		tagLibrary.setCreator (BSF_TAG, new BSFCreator ());
		tagLibrary.setSetter (BSF_TAG, SRC_ATTR, DoNothingSetter.getInstance ());
		tagLibrary.setSetter (BSF_TAG, LANG_ATTR, DoNothingSetter.getInstance ());
		tagLibrary.setSetter (BSF_TAG, RETURN_ATTR, DoNothingSetter.getInstance ());
	}

	private CookBSFLib ()
	{
	}
}
