/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookbsh;

import cookxml.core.setter.DoNothingSetter;
import cookxml.core.taglibrary.InheritableTagLibrary;

/**
 * This is the BeanShell (http://http://www.beanshell.org/) extension for CookXml.
 * The tag has a single attribute "src" for loading source code from a resource.
 * 
 * @author Heng Yuan
 * @version $Id: CookBSHLib.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookBSH 1.0
 */
public class CookBSHLib
{
	public static String BSH_TAG = "bsh";
	public static String SRC_ATTR = "src";

	/**
	 * Adds &lt;bsh> tag to the tag library specified.
	 * 
	 * @param	tagLibrary
	 *			the tag library to be setup
	 * @since	CookBSH 1.0
	 */
	public static void setupTags (InheritableTagLibrary tagLibrary)
	{
		tagLibrary.setCreator (BSH_TAG, new BSHCreator ());
		tagLibrary.setSetter (BSH_TAG, SRC_ATTR, DoNothingSetter.getInstance ());
	}

	private CookBSHLib ()
	{
	}
}
