/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookformlayout.adder;

import java.awt.*;

import com.jgoodies.forms.builder.AbstractFormBuilder;
import com.jgoodies.forms.layout.FormLayout;

import cookxml.cookformlayout.helper.AbstractFormBuilderHelper;
import cookxml.cookformlayout.helper.CellConstraintsHelper;
import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Adder;

/**
 * @author Heng Yuan
 * @version $Id: CellConstraintsAdder.java 235 2007-06-06 08:35:47Z coconut $
 * @since CookFormLayout 1.0
 */
public class CellConstraintsAdder implements Adder
{
	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine)
	{
		if (parent == null || !(parent instanceof CellConstraintsHelper) ||
		    child == null || !(child instanceof Component))
			return false;

		Object tmp = decodeEngine.getParent (parent);

		if (tmp == null)
			throw new NullPointerException ("Parent tag of cellconstraints cannot be null");

		if (tmp instanceof AbstractFormBuilderHelper)
		{
			AbstractFormBuilder builder = ((AbstractFormBuilderHelper)tmp).getFormBuilder ();
			builder.add ((Component)child, ((CellConstraintsHelper)parent).getCellConstraints ());
		}
		else if (tmp instanceof FormLayout)
		{
			tmp = decodeEngine.getParent (tmp);
			if (tmp == null ||
			    !(tmp instanceof Container))
				return false;

			Container container = (Container)tmp;
			container.add ((Component)child, ((CellConstraintsHelper)parent).getCellConstraints ());
		}
		else
			throw new IllegalArgumentException ("Parent object of cellconstraints is not valid.");

		return true;
	}
}
