/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookformlayout.converter;

import com.jgoodies.forms.layout.CellConstraints;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.ConverterException;
import cookxml.core.interfaces.Converter;

/**
 * @see CellConstraints
 * @see CellConstraints.Alignment
 * @author Heng Yuan
 * @version $Id: AlignmentConverter.java 235 2007-06-06 08:35:47Z coconut $
 * @since CookFormLayout 1.0
 */
public class AlignmentConverter implements Converter
{
	private final static AlignmentConverter s_instance = new AlignmentConverter ();

	public static AlignmentConverter getInstance ()
	{
		return AlignmentConverter.s_instance;
	}

	private AlignmentConverter ()
	{
	}

	public Object convert (String value, DecodeEngine decodeEngine) throws ConverterException
	{
		String str = value.toLowerCase ();
		if (str.equals ("d") || str.equals ("default"))
			return CellConstraints.DEFAULT;
		else if (str.equals ("f") || str.equals ("fill"))
			return CellConstraints.FILL;
		else if (str.equals ("c") || str.equals ("center"))
			return CellConstraints.CENTER;
		else if (str.equals ("l") || str.equals ("left"))
			return CellConstraints.LEFT;
		else if (str.equals ("r") || str.equals ("right"))
			return CellConstraints.RIGHT;
		else if (str.equals ("t") || str.equals ("top"))
			return CellConstraints.TOP;
		else if (str.equals ("b") || str.equals ("bottom"))
			return CellConstraints.BOTTOM;
		else
			throw new IllegalArgumentException (
					"Invalid alignment " + value
					+ ". Must be one of: left, center, right, top, bottom, "
					+ "fill, default, l, c, r, t, b, f, d.");
	}
}
