/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookformlayout.creator;

import javax.swing.*;

import org.w3c.dom.Element;

import cookxml.cookformlayout.CookFormLayoutLib;
import cookxml.cookformlayout.helper.ButtonBarBuilderHelper;
import cookxml.cookformlayout.helper.ButtonStackBuilderHelper;
import cookxml.cookformlayout.helper.DefaultFormBuilderHelper;
import cookxml.cookformlayout.helper.PanelBuilderHelper;
import cookxml.core.CookXml;
import cookxml.core.DecodeEngine;
import cookxml.core.exception.CookXmlException;
import cookxml.core.exception.CreatorException;
import cookxml.core.interfaces.Creator;

/**
 * @author Heng Yuan
 * @version $Id: FormBuilderCreator.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookFormLayout 1.0
 */
public class FormBuilderCreator implements Creator
{
	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine) throws CreatorException
	{
		if (parentObj == null)
			throw new NullPointerException ("Parent cannot be null.");
		if (!(parentObj instanceof JPanel))
			throw new IllegalArgumentException ("Parent is not a JPanel instance.");

		CookXml cookXml = decodeEngine.getCookXml ();
		JPanel panel = (JPanel)parentObj;
		String tag = elm.getTagName ();
		if (CookFormLayoutLib.PANEL_BUILDER_TAG.equals (tag))
			return new PanelBuilderHelper (cookXml, panel);
		if (CookFormLayoutLib.DEFAULT_FORM_BUILDER_TAG.equals (tag))
			return new DefaultFormBuilderHelper (cookXml, panel);
		if (CookFormLayoutLib.BUTTON_BAR_BUILDER_TAG.equals (tag))
			return new ButtonBarBuilderHelper (cookXml, panel);
		if (CookFormLayoutLib.BUTTON_STACK_BUILDER_TAG.equals (tag))
			return new ButtonStackBuilderHelper (cookXml, panel);
		return null;
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine) throws CookXmlException
	{
		return obj;
	}
}
