/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookformlayout.creator;

import java.lang.reflect.Constructor;

import org.w3c.dom.Element;

import cookxml.cookformlayout.helper.AbstractFormBuilderHelper;
import cookxml.cookformlayout.helper.FormBuilderHelper;
import cookxml.core.CookXml;
import cookxml.core.DecodeEngine;
import cookxml.core.exception.CookXmlException;
import cookxml.core.exception.CreatorException;
import cookxml.core.exception.NoDefaultConstructorException;
import cookxml.core.interfaces.Creator;

/**
 * @author Heng Yuan
 * @version $Id: FormBuilderHelperCreator.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookFormLayout 1.0
 */
public class FormBuilderHelperCreator implements Creator
{
	private final static Class[] EMPTY_CLASS_PARAM = new Class[0];
	public final static Object[] EMPTY_OBJECT_PARAM = new Object[0];

	public static Creator getCreator (Class parentClass, Class targetClass) throws CookXmlException
	{
		if (!FormBuilderHelper.class.isAssignableFrom (targetClass))
			throw new IllegalArgumentException (parentClass + " must be a FormBuilderHelper class.");

		try
		{
			Constructor ctor = targetClass.getConstructor (EMPTY_CLASS_PARAM);
			return new FormBuilderHelperCreator (parentClass, ctor);
		}
		catch (Exception ex)
		{
			CookXml.getDefaultExceptionHandler ().handleException (null, new NoDefaultConstructorException (targetClass));
			return null;
		}
	}

	private final Class m_parentClass;
	private final Constructor m_ctor;

	private FormBuilderHelperCreator (Class parentClass, Constructor ctor)
	{
		m_parentClass = parentClass;
		m_ctor=  ctor;
	}

	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine) throws CreatorException
	{
		try
		{
			if (parentObj == null || !m_parentClass.isInstance (parentObj))
				throw new IllegalArgumentException ("Tag " + elm.getTagName () + " cannot be appear under " + parentTag);

			decodeEngine.setDoAdd (false);
			return m_ctor.newInstance (EMPTY_OBJECT_PARAM);
		}
		catch (Exception ex)
		{
			throw new CreatorException (decodeEngine, ex, this, parentNS, parentTag, elm, parentObj);
		}
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine) throws CookXmlException
	{
		((FormBuilderHelper)obj).addToBuilder (((AbstractFormBuilderHelper)parentObj).getFormBuilder ());
		return obj;
	}
}
