/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookformlayout.helper;

import java.awt.*;
import javax.swing.*;

import com.jgoodies.forms.builder.AbstractFormBuilder;
import com.jgoodies.forms.layout.FormLayout;

import cookxml.core.CookXml;
import cookxml.core.interfaces.NoAdd;

/**
 * @author Heng Yuan
 * @version $Id: AbstractFormBuilderHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookFormLayout 1.0
 */
public abstract class AbstractFormBuilderHelper implements NoAdd
{
	private final CookXml m_cookXml;
	private final JPanel m_panel;
	private FormLayout m_layout;

	private AbstractFormBuilder m_builder;

	public AbstractFormBuilderHelper (CookXml cookXml, JPanel panel)
	{
		m_cookXml = cookXml;
		m_panel = panel;
	}

	/**
	 * This function is to be overridden by child class to construct an
	 * AbstractFormBuilder.  Call getLayout () and getPanel () functions
	 * to obtain the necessary constructor parameters.
	 * @return  a new instance of AbstractFormBuilder
	 */
	protected abstract AbstractFormBuilder createFormBuilder ();

	public CookXml getCookXml ()
	{
		return m_cookXml;
	}

	public FormLayout getLayout ()
	{
		return m_layout;
	}

	public JPanel getPanel ()
	{
		return m_panel;
	}

	public AbstractFormBuilder getFormBuilder ()
	{
		if (m_builder != null)
			return m_builder;
		AbstractFormBuilder formBuilder = createFormBuilder ();
		m_builder = formBuilder;
		return formBuilder;
	}

	public void add (FormLayout layout)
	{
		this.m_layout = layout;
	}

	public void add (Component component)
	{
		getFormBuilder ().add (component);
	}

	public void add (FormBuilderHelper helper)
	{
		helper.addToBuilder (getFormBuilder ());
	}
}
