/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookformlayout.helper;

import java.awt.*;
import java.util.Iterator;
import java.util.LinkedList;
import javax.swing.*;

import com.jgoodies.forms.builder.AbstractFormBuilder;
import com.jgoodies.forms.builder.ButtonBarBuilder;
import com.jgoodies.forms.builder.ButtonStackBuilder;

/**
 * @author Heng Yuan
 * @version $Id: AddHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookFormLayout 1.0
 */
public class AddHelper implements FormBuilderHelper
{
	public boolean fixed = false;
	public boolean related = true;
	public boolean narrow = false;
	public boolean growing = false;

	private Object m_comp;

	public void addToBuilder (AbstractFormBuilder builder)
	{
		if (m_comp == null)
			return;
		if (builder instanceof ButtonBarBuilder)
		{
			if (m_comp instanceof JComponent)
				addComponent ((ButtonBarBuilder)builder, (JComponent)m_comp, true);
			else
			{
				for (Iterator iter = ((LinkedList)m_comp).iterator (); iter.hasNext ();)
					addComponent ((ButtonBarBuilder)builder, (JComponent)iter.next (), !iter.hasNext ());
			}
		}
		else if (builder instanceof ButtonStackBuilder)
		{
			if (m_comp instanceof JComponent)
				addComponent ((ButtonStackBuilder)builder, (JComponent)m_comp, true);
			else
			{
				for (Iterator iter = ((LinkedList)m_comp).iterator (); iter.hasNext ();)
					addComponent ((ButtonStackBuilder)builder, (JComponent)iter.next (), !iter.hasNext ());
			}
		}
	}

	private void addComponent (ButtonBarBuilder builder, JComponent comp, boolean last)
	{
		if (fixed)
		{
			if (narrow)
				builder.addFixedNarrow (comp);
			else
				builder.addFixed (comp);
		}
		else
		{
			if (growing)
				builder.addGriddedGrowing (comp);
			else
				builder.addGridded (comp);
		}
		if (!last)
		{
			if (related)
				builder.addRelatedGap ();
			else
				builder.addUnrelatedGap ();
		}
	}

	private void addComponent (ButtonStackBuilder builder, JComponent comp, boolean last)
	{
		if (fixed)
			builder.addFixed (comp);
		else
			builder.addGridded (comp);
		if (!last)
		{
			if (related)
				builder.addRelatedGap ();
			else
				builder.addUnrelatedGap ();
		}
	}

	public void setGridded (boolean b)
	{
		fixed = !b;
	}

	public void add (Component c)
	{
		if (m_comp == null)
			m_comp = c;
		else if (m_comp instanceof Component)
		{
			LinkedList list = new LinkedList ();
			list.add (m_comp);
			list.add (c);
			m_comp = list;
		}
		else
		{
			((LinkedList)m_comp).add (c);
		}
	}
}
