/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookformlayout.helper;

import com.jgoodies.forms.builder.AbstractFormBuilder;
import com.jgoodies.forms.builder.DefaultFormBuilder;

/**
 * @author Heng Yuan
 * @version $Id: AppendHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookFormLayout 1.0
 */
public class AppendHelper implements FormBuilderHelper
{
	public final static String GLUE = "glue";
	public final static String LABEL_COMPONENTS_GAP = "labelComponentsGap";
	public final static String LINE_GAP = "lineGap";
	public final static String PARAGRAPH_GAP = "paragraphGap";
	public final static String RELATED_COMPONENTS_GAP = "relatedComponentsGap";
	public final static String UNRELATED_COMPONENTS_GAP = "unrelatedComponentsGap";

	public String row;
	public String column;

	public void addToBuilder (AbstractFormBuilder builder)
	{
		if (column != null)
		{
			if (GLUE.equalsIgnoreCase (column))
				builder.appendGlueColumn ();
			else if (LABEL_COMPONENTS_GAP.equalsIgnoreCase (column))
				builder.appendLabelComponentsGapColumn ();
			else if (RELATED_COMPONENTS_GAP.equalsIgnoreCase (column))
				builder.appendRelatedComponentsGapColumn ();
			else if (UNRELATED_COMPONENTS_GAP.equalsIgnoreCase (column))
				builder.appendUnrelatedComponentsGapColumn ();
			else
				builder.appendColumn (column);
		}

		if (row != null)
		{
			if (GLUE.equalsIgnoreCase (row))
				builder.appendGlueRow ();
			else if (LINE_GAP.equalsIgnoreCase (row) && builder instanceof DefaultFormBuilder)
				builder.appendRow (((DefaultFormBuilder)builder).getLineGapSpec ());
			else if (PARAGRAPH_GAP.equalsIgnoreCase (row))
				builder.appendParagraphGapRow ();
			else if (RELATED_COMPONENTS_GAP.equalsIgnoreCase (row))
				builder.appendRelatedComponentsGapRow ();
			else if (UNRELATED_COMPONENTS_GAP.equalsIgnoreCase (row))
				builder.appendUnrelatedComponentsGapRow ();
			else
				builder.appendRow (row);
		}
	}
}
