/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookformlayout.helper;

import java.awt.*;
import java.util.StringTokenizer;

import com.jgoodies.forms.layout.CellConstraints;

import cookxml.cookformlayout.converter.AlignmentConverter;
import cookxml.core.interfaces.Helper;

/**
 * @author Heng Yuan
 * @version $Id: CellConstraintsHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookFormLayout 1.0
 */
public class CellConstraintsHelper implements Helper
{
	private static final Insets EMPTY_INSETS = new Insets(0, 0, 0, 0);

	public int gridX = 1;
	public int gridY = 1;
	public int gridWidth = 1;
	public int gridHeight = 1;
	public CellConstraints.Alignment hAlign = CellConstraints.DEFAULT;
	public CellConstraints.Alignment vAlign = CellConstraints.DEFAULT;
	public Insets insets;

	public CellConstraints value;

	public CellConstraints getCellConstraints ()
	{
		if (value == null)
			value = new CellConstraints (gridX, gridY, gridWidth, gridHeight, hAlign, vAlign, insets == null ? EMPTY_INSETS : insets);
		else if (insets != null)
			value.insets = insets;

		return value;
	}

	public void setXY (String value)
	{
		StringTokenizer tok = new StringTokenizer (value, ", ");
		gridX = Integer.parseInt (tok.nextToken ());
		gridY = Integer.parseInt (tok.nextToken ());

		if (tok.hasMoreTokens ())
			hAlign = (CellConstraints.Alignment)AlignmentConverter.getInstance ().convert (tok.nextToken (), null);
		if (tok.hasMoreTokens ())
			vAlign = (CellConstraints.Alignment)AlignmentConverter.getInstance ().convert (tok.nextToken (), null);
	}

	public void setXYW (String value)
	{
		StringTokenizer tok = new StringTokenizer (value, ", ");
		gridX = Integer.parseInt (tok.nextToken ());
		gridY = Integer.parseInt (tok.nextToken ());
		gridWidth = Integer.parseInt (tok.nextToken ());

		if (tok.hasMoreTokens ())
			hAlign = (CellConstraints.Alignment)AlignmentConverter.getInstance ().convert (tok.nextToken (), null);
		if (tok.hasMoreTokens ())
			vAlign = (CellConstraints.Alignment)AlignmentConverter.getInstance ().convert (tok.nextToken (), null);
	}

	public void setXYWH (String value)
	{
		StringTokenizer tok = new StringTokenizer (value, ", ");
		gridX = Integer.parseInt (tok.nextToken ());
		gridY = Integer.parseInt (tok.nextToken ());
		gridWidth = Integer.parseInt (tok.nextToken ());
		gridHeight = Integer.parseInt (tok.nextToken ());

		if (tok.hasMoreTokens ())
			hAlign = (CellConstraints.Alignment)AlignmentConverter.getInstance ().convert (tok.nextToken (), null);
		if (tok.hasMoreTokens ())
			vAlign = (CellConstraints.Alignment)AlignmentConverter.getInstance ().convert (tok.nextToken (), null);
	}

	public void setColAlign (CellConstraints.Alignment value)
	{
		hAlign = value;
	}

	public void setRowAlign (CellConstraints.Alignment value)
	{
		vAlign = value;
	}

	public Object getFinalObject () throws Exception
	{
		return getCellConstraints ();
	}
}
