/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookformlayout.helper;

import java.awt.*;
import javax.swing.*;

import com.jgoodies.forms.builder.AbstractFormBuilder;
import com.jgoodies.forms.builder.DefaultFormBuilder;
import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.ComponentFactory;
import com.jgoodies.forms.factories.DefaultComponentFactory;
import com.jgoodies.forms.layout.CellConstraints;

import cookxml.cookformlayout.FormLayoutUtils;
import cookxml.core.CookXml;

/**
 * @author Heng Yuan
 * @version $Id: SeparatorHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookFormLayout 1.0
 */
public class SeparatorHelper implements FormBuilderHelper
{
	public String text="";
	public CellConstraints cellConstraints;
	public int columnSpan = 0;
	public int alignment = SwingConstants.LEFT;

	public void addToBuilder (AbstractFormBuilder builder)
	{
		if (builder instanceof DefaultFormBuilder && cellConstraints == null && columnSpan <= 0)
		{
			((DefaultFormBuilder)builder).appendSeparator (text);
			return;
		}

		if (builder instanceof PanelBuilder)
		{
			if (columnSpan > 0)
				((PanelBuilder)builder).addSeparator (text, columnSpan);
			else if (cellConstraints != null)
				((PanelBuilder)builder).addSeparator (text, cellConstraints);
			else
				((PanelBuilder)builder).addSeparator (text);
			return;
		}
	}

	public void addToFormLayout (CookXml cookXml, Container container)
	{
		JComponent comp = getComponent (cookXml);
		container.add (comp, cellConstraints);
	}

	public JComponent getComponent (CookXml cookXml)
	{
		ComponentFactory factory = FormLayoutUtils.getComponentFactory (cookXml);
		if (factory == null)
			factory = DefaultComponentFactory.getInstance ();
		return factory.createSeparator (text, alignment);
	}
}
