/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package examples.cookformlayout;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import cookxml.cookformlayout.CookFormLayoutLib;
import cookxml.cookswing.CookSwing;
import cookxml.core.util.TextUtils;

import examples.util.XmlToHtmlConverter;

/**
 * This is the demo to load CookFormLayout examples.
 * @author Heng Yuan
 */
public class CookFormLayoutDemo
{
	public JFrame rootFrame;
	public JPanel swingPane;
	public JEditorPane xmlPane;

	public WindowListener frameListener = new WindowAdapter ()
	{
		public void windowClosing (WindowEvent e)
		{
			doExit ();
		}
	};

	public ActionListener exitAction = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			doExit ();
		}
	};

	public ActionListener menuAction = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			JMenuItem item = (JMenuItem)e.getSource ();
			String name = item.getText ();
			doOpenXml ("examples/cookformlayout/xml/" + name);
		}
	};

	public ActionListener comboBoxAction = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			JComboBox box = (JComboBox)e.getSource ();
			String name = (String)box.getSelectedItem ();
			doOpenXml ("examples/cookformlayout/xml/" + name);
		}
	};

	public void doOpenXml (String input)
	{
		CookSwing cookSwing = new CookSwing (this);		// just to for hooking up buttonAction
		Container container = cookSwing.render (input);
		if (container == null)
			return;
		if (container instanceof JFrame ||
		    container instanceof JDialog)
		{
			container.setVisible (true);
		}
		else
		{
			swingPane.removeAll ();
			swingPane.add (container);
			swingPane.revalidate ();
			swingPane.repaint ();
		}

		String html;
		try
		{
			html = XmlToHtmlConverter.convert ("", TextUtils.readText (input));
		}
		catch (Exception ex)
		{
			html = "<html><body><h1>Error reading XML code.</h1></body></html>";
		}
		xmlPane.setText (html);
		rootFrame.pack ();
	}

	public void doExit ()
	{
		System.exit (0);
	}

	public static void main (String[] args)
	{
		CookFormLayoutLib.setupTags (CookSwing.getSwingTagLibrary ());
		CookSwing cookSwing = new CookSwing (new CookFormLayoutDemo ());
		cookSwing.render ("examples/cookformlayout/xml/cookformlayoutdemo.xml").setVisible (true);
	}
}
