/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjface.setter;

import org.eclipse.jface.viewers.Viewer;
import org.eclipse.swt.widgets.Control;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.SetterException;
import cookxml.core.interfaces.Setter;
import cookxml.core.setter.DefaultSetter;

/**
 * This is an setter that takes control from a view, instead of the view itself, to be used
 * in calling setControl.
 * @author Heng Yuan
 * @see Control
 */
public class SetControlSetter implements Setter
{
	private final static Setter s_instance = new SetControlSetter ();

	public static Setter getInstance ()
	{
		return s_instance;
	}

	private SetControlSetter ()
	{
	}

	public void setAttribute (String ns, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine) throws SetterException
	{
		if (value == null ||
			!((value instanceof Control) ||
			  (value instanceof Viewer)))
			return;
		Control control;
		if (value instanceof Control)
			control = (Control)value;
		else
			control = ((Viewer)value).getControl ();
		DefaultSetter.getInstance ().setAttribute (ns, tag, attrNS, attr, obj, control, decodeEngine);
	}
}
