/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjface.ui;

import java.util.List;

import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.ComboBoxCellEditor;
import org.eclipse.jface.viewers.ICellModifier;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.TableItem;

/**
 * @author Heng Yuan
 */
public class ArrayCellModifier implements ICellModifier
{
    public boolean readOnly;
    private final TableViewer m_tableViewer;

	public ArrayCellModifier (TableViewer viewer)
	{
		m_tableViewer = viewer;
	}

	public boolean canModify (Object element, String property)
	{
		return !readOnly;
	}

	public Object getValue (Object element, String property)
	{
        Object[] properties = m_tableViewer.getColumnProperties ();
		int col = 0;
		for (int i = 0; i < properties.length; ++i)
			if (properties[i] == property)
				col = i;
		if (element instanceof Object[])
			return prepareData (((Object[])element)[col], col);
		if (element instanceof List)
		{
			List list = (List)element;
			if (list.size () > col)
				return prepareData (list.get (col), col);
		}
		return "";
	}

	public void modify (Object element, String property, Object value)
	{
		Object[] properties = m_tableViewer.getColumnProperties ();
		int col = 0;
		for (int i = 0; i < properties.length; ++i)
			if (properties[i] == property)
				col = i;
		TableItem item = (TableItem) element;
		element = item.getData ();
		if (element instanceof Object[])
		{
			((Object[])element)[col] = value;
			if (value == null)
				item.setText (col, "");
			else if (value instanceof Image)
				item.setImage (col, (Image)value);
			else
				item.setText (col, value.toString ());
			return;
		}
		if (element instanceof List)
		{
			List list = (List)element;
			if (list.size () > col)
			{
				list.set (col, value);
				item.setData (element);
			}
			return;
		}
	}

    private Object prepareData (Object value, int column)
	{
		CellEditor cellEditor = m_tableViewer.getCellEditors ()[column];
		if (cellEditor instanceof ComboBoxCellEditor && (value instanceof String[]))
		{
			ComboBoxCellEditor comboEditor = (ComboBoxCellEditor)cellEditor;
			String[] items = comboEditor.getItems ();
			for (int i = 0; i < items.length; ++i)
				if (items[i] == value)
					return new Integer (i);
			return new Integer (0);
		}
        return value;
	}
}
