/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjface.ui;

import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.eclipse.jface.util.ListenerList;
import org.eclipse.jface.viewers.ILabelProviderListener;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.swt.graphics.Image;

/**
 * @author Heng Yuan
 */
public class ArrayTableLabelProvider implements ITableLabelProvider
{
	private ListenerList m_listeners = new ListenerList (1);

	public Image getColumnImage (Object element, int columnIndex)
	{
		Object obj = getArrayObject (element, columnIndex);
		if (obj instanceof Image)
			return (Image)obj;
		return null;
	}

	public String getColumnText (Object element, int columnIndex)
	{
		Object obj = getArrayObject (element, columnIndex);
		if (obj == null)
			return "";
		return obj.toString ();
	}

	public void addListener (ILabelProviderListener listener)
	{
		m_listeners.add (listener);
	}

	public void removeListener (ILabelProviderListener listener)
	{
		m_listeners.remove (listener);
	}

	public void dispose ()
	{
	}

	public boolean isLabelProperty (Object element, String property)
	{
		return false;
	}

	private static Object getArrayObject (Object element, int columnIndex)
	{
		if (element instanceof Object[])
		{
			Object[] array = (Object[])element;
			if (array.length > columnIndex)
				return array[columnIndex];
			return null;
		}
		if (element instanceof List)
			return ((List)element).get (columnIndex);
		if (element instanceof Collection)
		{
			Iterator iter = ((Collection)element).iterator ();
			for (int i = 0; i < columnIndex; ++i)
				iter.next ();
			return iter.next ();
		}
		if (element instanceof Map.Entry && columnIndex < 2)
		{
			Map.Entry entry = (Map.Entry)element;
			if (columnIndex == 0)
				return entry.getKey ();
			return entry.getValue ();
		}
		return null;
	}
}
