/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjface.ui;

import org.eclipse.jface.action.CoolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.StatusLineManager;
import org.eclipse.jface.action.ToolBarManager;
import org.eclipse.jface.window.ApplicationWindow;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;

/**
 * @author Heng Yuan
 */
public final class CJApplicationWindow extends ApplicationWindow
{
	private CoolBarManager m_coolBarManager;
	private MenuManager m_menuManager;
	private StatusLineManager m_statusLineManager;
	private ToolBarManager m_toolBarManager;
	private Boolean m_showTopSeparator;
	private WindowContentProvider m_appContentProvider;

	public CJApplicationWindow ()
	{
		this (null);
	}

	public CJApplicationWindow (Shell parentShell)
	{
		super (parentShell);
	}

	public void add (WindowContentProvider appContentProvider)
	{
		if (appContentProvider == null)
			return;
		m_appContentProvider = appContentProvider;
	}

	public void add (CoolBarManager coolBarManager)
	{
		if (coolBarManager == null)
			return;
		m_coolBarManager = coolBarManager;
		addCoolBar (SWT.NONE);
	}

	public void add (MenuManager menuManager)
	{
		m_menuManager = menuManager;
		addMenuBar ();
	}

	public void add (StatusLineManager statusLineManager)
	{
		m_statusLineManager = statusLineManager;
		addStatusLine ();
	}

	public void add (ToolBarManager toolBarManager)
	{
		m_toolBarManager = toolBarManager;
		addToolBar (SWT.NONE);
	}

	public void setShowTopSeparator (Boolean b)
	{
		m_showTopSeparator = b;
	}

	protected Control createContents (Composite parent)
	{
		if (m_appContentProvider == null)
			return super.createContents (parent);
		return m_appContentProvider.createContents (parent);
	}

	protected CoolBarManager createCoolBarManager (int style)
	{
		return m_coolBarManager;
	}

	protected MenuManager createMenuManager ()
	{
		return m_menuManager;
	}

	protected StatusLineManager createStatusLineManager ()
	{
		return m_statusLineManager;
	}

	protected ToolBarManager createToolBarManager (int style)
	{
		return m_toolBarManager;
	}

	protected boolean showTopSeparator ()
	{
		if (m_showTopSeparator == null)
			return super.showTopSeperator ();
		return m_showTopSeparator.booleanValue ();
	}
}
