/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjface.ui;

import org.eclipse.jface.viewers.Viewer;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;

import cookxml.cookjface.CookJFace;
import cookxml.core.CookXml;
import cookxml.core.util.DocumentElement;

/**
 * This content provider is used to generate content from XML.
 *
 * @author Heng Yuan
 */
public class XmlContentProvider implements WindowContentProvider
{
	/**
	 * The XML document source.
	 */
	private DocumentElement m_xml;
	/**
	 * Object where all the variables are located.
	 */
	private Object m_varObj;

	/**
	 * Set the XML source.
	 *
	 * @param xml the XML source.
	 */
	public void setXml (DocumentElement xml)
	{
		m_xml = xml;
	}

	/**
	 * Get the variable object.
	 *
	 * @return	the variable object.
	 */
	public Object getVarObj ()
	{
		return m_varObj;
	}

	/**
	 * Set the variable object.
	 *
	 * @param varObj the variable object.
	 */
	public void setVarObj (Object varObj)
	{
		m_varObj = varObj;
	}

	public Control createContents (Composite parent)
	{
		try
		{
			if (m_xml == null)
				return null;
			Object obj = new CookJFace (m_varObj).xmlDecode (m_xml, null, "composite", parent);
			if (obj instanceof Control)
				return (Control)obj;
			if (obj instanceof Viewer)
				return ((Viewer)obj).getControl ();
		}
		catch (Exception ex)
		{
			assert CookXml.debug (ex);
		}
		return null;
	}
}
