/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjs;

import cookxml.core.setter.DoNothingSetter;
import cookxml.core.taglibrary.InheritableTagLibrary;

/**
 * This is the JavaScript extension for CookXml using Mozilla Rhino (http://www.mozilla.org/rhino/).
 *
 * @author Heng Yuan
 * @version $Id: CookJSLib.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookJS 1.0
 */
public class CookJSLib
{
	public static String JS_TAG = "js";
	public static String SRC_ATTR = "src";
	public static String DEFAULT_SRC_NAME = "<js>";

	private static boolean s_usingProxyJavaAdapter = false;
	private static boolean s_disablingOptimization = false;

	/**
	 * Adds &lt;bsh> tag to the tag library specified.
	 * @param	tagLibrary
	 *			the tag library to be setup
	 * @since	CookJS 1.0
	 */
	public static void setupTags (InheritableTagLibrary tagLibrary)
	{
		tagLibrary.setCreator (JS_TAG, new JSCreator ());
		tagLibrary.setSetter (JS_TAG, SRC_ATTR, DoNothingSetter.getInstance ());
	}

	public static boolean isUsingProxyJavaAdapter ()
	{
		return s_usingProxyJavaAdapter;
	}

	/**
	 * Set true if you want to use ProxyJavaAdapter, which is a JDK 1.3 feature
	 * that allows dynamic binding of JavaScript object functions etc to Java
	 * objects.  This approach does not involve creating a ClassLoader, which
	 * Rhino JavaScript's own JavaAdapter class uses.  Creating a ClassLoader
	 * can cause permission exception from SecurityManager if there is one.
	 *
	 * The main benefit of using ProxyJavaAdapter is to allow JavaScript embedded
	 * programs running in Java Web Start or Applet in a Sandbox without signed
	 * jars.
	 *
	 * @param	b
	 *			use or not
	 */
	public static void setUsingProxyJavaAdapter (boolean b)
	{
		s_usingProxyJavaAdapter = b;
	}

	public static boolean isDisablingOptimization ()
	{
		return s_disablingOptimization;
	}

	public static void setDisablingOptimization (boolean disablingOptimization)
	{
		s_disablingOptimization = disablingOptimization;
	}
}
