/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjs;

import org.mozilla.javascript.Context;
import org.mozilla.javascript.Scriptable;

import cookxml.core.CookXml;
import cookxml.core.IdReference;

/**
 * This is a scope class for JavaScript which serves to report CookXml's objects associated
 * with Ids.
 *
 * @author Heng Yuan
 * @version $Id: CookXmlScope.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookJS 1.0
 */
class CookXmlScope implements Scriptable
{
	private final CookXml m_cookXml;
	private Scriptable m_parentScope;
	private Scriptable m_prototype;

	public CookXmlScope (CookXml cookXml)
	{
		m_cookXml = cookXml;
	}

	public Object get (String name, Scriptable start)
	{
		IdReference idRef = m_cookXml.getId (name);
		if (idRef != null)
			return Context.javaToJS (idRef.object, start);
		return NOT_FOUND;
	}

	public Object get (int index, Scriptable start)
	{
		return NOT_FOUND;
	}

	public boolean has (String name, Scriptable start)
	{
		IdReference idRef = m_cookXml.getId (name);
		if (idRef != null)
			return true;
		return false;
	}

	public boolean has (int index, Scriptable start)
	{
		return false;
	}

	public void put (String name, Scriptable start, Object value)
	{
	}

	public void put (int index, Scriptable start, Object value)
	{
	}

	public void delete (String name)
	{
	}

	public void delete (int index)
	{
	}

	public Scriptable getPrototype ()
	{
		return m_prototype;
	}

	public void setPrototype (Scriptable prototype)
	{
		m_prototype = prototype;
	}

	public Scriptable getParentScope ()
	{
		return m_parentScope;
	}

	public void setParentScope (Scriptable parent)
	{
		m_parentScope = parent;
	}

	public Object[] getIds ()
	{
		return new Object[0];
	}

	public Object getDefaultValue (Class hint)
	{
		return null;
	}

	public boolean hasInstance (Scriptable instance)
	{
		return false;
	}

	public String getClassName ()
	{
		return "CookXmlScope";
	}
}
