/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjs;

import org.mozilla.javascript.Context;
import org.mozilla.javascript.ImporterTopLevel;
import org.mozilla.javascript.NativeObject;
import org.mozilla.javascript.Scriptable;
import org.w3c.dom.CharacterData;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import cookxml.cookjs.util.ProxyJavaAdapter;
import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Creator;
import cookxml.core.util.TextUtils;

/**
 * This creator creates a new JavaScript interpreter.  It creates a hierarchy of scopes
 * ImporterTopLevel -> Context scope -> CookXmlScope -> NativeObject scope (for actual interpretation).
 *
 * @author Heng Yuan
 * @version $Id: JSCreator.java 231 2007-06-06 07:14:28Z coconut $
 * @since CookJS 1.0
 */
class JSCreator implements Creator
{
	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine) throws Exception
	{
		Context cx = Context.enter ();
		try
		{
			decodeEngine.setDoAdd (false);

			String src = elm.getAttribute (CookJSLib.SRC_ATTR);
			String code;

			if (src == null || src.length () == 0)
			{
				Node node = elm.getFirstChild ();
				if (node == null || (!(node instanceof CharacterData)))
					return null;
				code = ((CharacterData)node).getData ();
			}
			else
			{
				code = TextUtils.readText (src, decodeEngine.getCookXml ().getClassLoader ());
				if (code == null)
					return null;
				src = CookJSLib.DEFAULT_SRC_NAME;
			}

			Scriptable scope = cx.initStandardObjects (new ImporterTopLevel ());
			if (CookJSLib.isDisablingOptimization ())
				cx.setOptimizationLevel (-1);

			if (CookJSLib.isUsingProxyJavaAdapter ())
				ProxyJavaAdapter.init (cx, scope, true);

			CookXmlScope cookXmlScope = new CookXmlScope (decodeEngine.getCookXml ());
			cookXmlScope.setParentScope (scope);

			Scriptable subScope = new NativeObject ();
			subScope.setParentScope (cookXmlScope);
			Object result = cx.evaluateString (subScope, code, src, 1, null);
			return Context.jsToJava (result, Object.class);
		}
		finally
		{
			Context.exit ();
		}
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine)
	{
		decodeEngine.addChild (parentNS, parentTag, elm, parentObj, obj);
		return obj;
	}
}
