/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjython;

import org.python.core.Py;
import org.python.core.PyObject;
import org.python.core.PyStringMap;

import cookxml.core.CookXml;
import cookxml.core.IdReference;

/**
 * This class is responsible for retrieving id from CookXml and use it as a global for Python.
 *
 * @since CookJython 1.0
 * @version $Id: CookJythonIdMap.java 215 2007-06-06 03:59:41Z coconut $
 * @author Heng Yuan
 */
class CookJythonIdMap extends PyStringMap
{
	private final CookXml m_cookXml;

	/**
	 * Sets up the globals for python using id's inside CookXml.
	 * @param	cookXml
	 *			the CookXml object in which all the ids are located.
	 */
    public CookJythonIdMap (CookXml cookXml)
	{
		m_cookXml = cookXml;
	}

	public PyObject __finditem__ (String s)
	{
		IdReference idRef = m_cookXml.getId (s);
		if (idRef != null)
			return Py.java2py (idRef.object);
		return super.__finditem__ (s);
	}
}
