/*
 * (c) Copyright 2005-2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjython;

import cookxml.core.setter.DoNothingSetter;
import cookxml.core.taglibrary.InheritableTagLibrary;

/**
 * Sets up tag libraries to add a tag for Jython.
 * <p>
 * Currently, it supports three optional attributes:
 * <ul>
 * <li>return="variable", useful if you intend to read an object from jython interpreter
 * <li>class="java class name", useful only when the object obtained from jython interpreter could not be converted
 * 		to the correct Java class.  In most cases, it is not needed.
 * <li>src="uri for the external python code", useful when you want to load source code from a resource
 * </ul>
 *
 * @author Heng Yuan
 * @version $Id: CookJythonLib.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookJython 1.0
 */
public class CookJythonLib
{
	public static String JYTHON_TAG = "jython";
	public static String SRC_ATTR = "src";
	public static String RETURN_ATTR = "return";
	public static String CLASS_ATTR = "class";

	/**
	 * Adds &lt;jython> tag to the tag library specified.
	 * 
	 * @param	tagLibrary
	 *			the tag library to be setup
	 */
	public static void setupTags (InheritableTagLibrary tagLibrary)
	{
		tagLibrary.setCreator (JYTHON_TAG, new JythonCreator ());
		tagLibrary.setSetter (JYTHON_TAG, SRC_ATTR, DoNothingSetter.getInstance ());
		tagLibrary.setSetter (JYTHON_TAG, CLASS_ATTR, DoNothingSetter.getInstance ());
		tagLibrary.setSetter (JYTHON_TAG, RETURN_ATTR, DoNothingSetter.getInstance ());
	}
}
