/*
 * (c) Copyright 2005-2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookjython;

import org.python.core.Py;
import org.python.core.PyObject;
import org.python.util.PythonInterpreter;
import org.w3c.dom.CharacterData;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Creator;
import cookxml.core.util.TextUtils;

/**
 * This class creates a Jython Interpreter instance and use it to interpret code within the tag.
 * 
 * @author Heng Yuan
 * @version $Id: JythonCreator.java 231 2007-06-06 07:14:28Z coconut $
 * @since CookJython 1.0
 */
class JythonCreator implements Creator
{
	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine) throws Exception
	{
		decodeEngine.setDoAdd (false);

		Class returnClass = Object.class;
		String classAttr = elm.getAttribute (CookJythonLib.CLASS_ATTR);
		if (classAttr != null && classAttr.length () > 0)
		{
			ClassLoader cl = decodeEngine.getCookXml ().getClassLoader ();
			returnClass = cl.loadClass (classAttr);
		}

		String src = elm.getAttribute (CookJythonLib.SRC_ATTR);
		String code;

		if (src == null || src.length () == 0)
		{
			Node node = elm.getFirstChild ();
			if (node == null || (!(node instanceof CharacterData)))
				return null;
			code = ((CharacterData)node).getData ();
		}
		else
		{
			code  = TextUtils.readText (src, decodeEngine.getCookXml ().getClassLoader ());
			if (code == null)
				return null;
		}

		PythonInterpreter inter = new PythonInterpreter ();
		inter.setLocals (new CookJythonIdMap (decodeEngine.getCookXml ()));
		inter.exec (code);

		PyObject returnValue = null;
		String returnAttr = elm.getAttribute (CookJythonLib.RETURN_ATTR);
		if (returnAttr != null && returnAttr.length () > 0)
			returnValue = inter.get (returnAttr);

		if (returnValue == null || returnValue == Py.None)
			return null;

		return returnValue.__tojava__ (returnClass);
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine)
	{
		decodeEngine.addChild (parentNS, parentTag, elm, parentObj, obj);
		return obj;
	}
}
