/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package examples.cookjython;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.*;

import cookxml.cookjython.CookJythonLib;
import cookxml.cookswing.CookSwing;
import cookxml.cookswing.CookSwingLib;
import cookxml.core.util.TextUtils;

import examples.util.XmlToHtmlConverter;

/**
 * @author Heng Yuan
 */
public class CookJythonDemo
{
	public String msgInvalidXmlFile;
	public String msgFileOpened;
	public String msgErrorReadingXml;

	public JPanel swingPane;
	public JEditorPane xmlPane;
	public JLabel statusBar;

	public ActionListener comboBoxAction = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			JComboBox box = (JComboBox)e.getSource ();
			String name = (String)box.getSelectedItem ();
			doOpenXml ("examples/cookjython/xml/" + name);
		}
	};

	public void doOpenXml (String input)
	{
		CookSwing cookSwing = new CookSwing (this);		// just to for hooking up buttonAction
		cookSwing.setId ("statusBar", CookSwingLib.NAMESPACE, "label", statusBar);	// for passing statusBar to scripts
		Container container = cookSwing.render (input);
		if (container == null)
		{
			setStatus (msgInvalidXmlFile + input);
			return;
		}
		if (container instanceof JFrame ||
			container instanceof JDialog)
		{
			container.setVisible (true);
		}
		else
		{
			swingPane.removeAll ();
			swingPane.add (container);
		}

		setStatus (msgFileOpened + input);

		String html = null;
		try
		{
			html = XmlToHtmlConverter.convert ("", TextUtils.readText (input));
		}
		catch (Exception ex)
		{
			html = msgErrorReadingXml;
		}
		xmlPane.setText (html);
	}

	public void setStatus (String text)
	{
		statusBar.setText (text);
	}

	public static void main (String[] args)
	{
		CookJythonLib.setupTags (CookSwing.getSwingTagLibrary ());
		new CookSwing (new CookJythonDemo ()).render ("examples/cookjython/xml/cookjythondemo.xml").setVisible (true);
	}
}
