/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.adder;

import java.util.*;
import javax.swing.table.DefaultTableModel;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Adder;

/**
 * This adder actually does a lot of things.  For a vector child, it would call
 * addRow function of DefaultTableModel.  For a map child, it would add all the
 * entries in the map as sorted by the key into the table that has two columns.
 *
 * @cxadder	java.util.Map
 * 			add map to the table model with one column for the key and one column
 * 			for the value.
 * @cxadder	java.util.Vector
 * 			Add the Vector to the end in the table model.
 * 
 * @see javax.swing.table.DefaultTableModel
 * @see java.util.Map
 * @see java.util.Vector
 * @author Heng Yuan
 * @version $Id: DefaultTableModelAdder.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.0
 */
public class DefaultTableModelAdder implements Adder
{
	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine)
	{
		if (parent == null || child == null ||
			!(parent instanceof DefaultTableModel))
			return false;

		if (child instanceof Vector)
		{
			((DefaultTableModel)parent).addRow ((Vector)child);
			return true;
		}

		if (child instanceof Map)
		{
			Map map = (Map)child;
			Set keySet = new TreeSet (map.keySet ());
			DefaultTableModel tableModel = (DefaultTableModel)parent;
			for (Iterator iter = keySet.iterator (); iter.hasNext ();)
			{
				Object key = iter.next ();
				Vector vector = new Vector ();
				vector.add (key);
				vector.add (map.get (key));
				tableModel.addRow (vector);
			}
			return true;
		}
		return false;
	}
}
