/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.adder;

import java.text.DateFormat;
import java.text.Format;
import java.text.NumberFormat;
import javax.swing.*;
import javax.swing.text.DateFormatter;
import javax.swing.text.DefaultFormatterFactory;
import javax.swing.text.InternationalFormatter;
import javax.swing.text.NumberFormatter;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Adder;

/**
 * @see javax.swing.JComboBox
 * @author Heng Yuan
 * @version $Id: FormatterAdder.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.2
 */
public class FormatterAdder implements Adder
{
	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine)
	{
		if (parent == null || child == null ||
			!(parent instanceof JFormattedTextField))
			return false;
		if (child instanceof Format)
		{
			DefaultFormatterFactory factory;
			if (child instanceof DateFormat)
				factory = new DefaultFormatterFactory(new DateFormatter((DateFormat)child));
			else if (child instanceof NumberFormat)
				factory = new DefaultFormatterFactory(new NumberFormatter((NumberFormat)child));
			else
				factory = new DefaultFormatterFactory(new InternationalFormatter((Format)child));
			((JFormattedTextField)parent).setFormatterFactory (factory);
		}
		else if (child instanceof JFormattedTextField.AbstractFormatter)
		{
			((JFormattedTextField)parent).setFormatterFactory (new DefaultFormatterFactory ((JFormattedTextField.AbstractFormatter)child));
		}
		else if (child instanceof JFormattedTextField.AbstractFormatterFactory)
		{
			((JFormattedTextField)parent).setFormatterFactory ((JFormattedTextField.AbstractFormatterFactory)child);
		}
		else
			return false;
		return true;
	}
}
