/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.adder;

import java.awt.*;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Adder;

/**
 * This adder is needed to add the Component within the GridBagLayoutConstraint parent
 * element to the container ancestor.
 *
 * @author Heng Yuan
 * @version $Id: GridBagLayoutConstraintsAdder.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.0
 */
public class GridBagLayoutConstraintsAdder implements Adder
{
	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine)
	{
		if (parent == null || child == null ||
			!(parent instanceof GridBagConstraints) ||
 			!(child instanceof Component))
			return false;

		Object containerParent = decodeEngine.getParent (parent);
		if (containerParent == null)
			return false;

		GridBagLayout gridbag = null;

		if (containerParent instanceof GridBagLayout)
		{
			gridbag = (GridBagLayout)containerParent;
			containerParent = decodeEngine.getParent (containerParent);
		}

		if (containerParent == null || !(containerParent instanceof Container))
			return false;

		Container container = (Container)containerParent;
		if (!(container.getLayout () instanceof GridBagLayout))
		{
			gridbag = new GridBagLayout ();
			container.setLayout (gridbag);
		}
		if (gridbag == null)	// hmm, should have this one, but somewhere there can be a logic hole
			gridbag = (GridBagLayout)container.getLayout ();

		GridBagConstraints constraints = (GridBagConstraints)parent;
		Component c = (Component)child;
		gridbag.setConstraints (c, constraints);
		container.add ((Component)child, parent);

		return true;
	}
}
