/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.adder;

import java.awt.*;

import cookxml.cookswing.helper.Constraint;
import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Adder;

/**
 * This adder is used by BorderLayout, CardLayout and OverlayLayout that
 * use constraint for the inner component.
 *
 * @see java.awt.BorderLayout
 * @see java.awt.CardLayout
 * @see javax.swing.OverlayLayout
 * @author Heng Yuan
 * @version $Id: LayoutConstraintAdder.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.0
 */
public class LayoutConstraintAdder implements Adder
{
	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine)
	{
		if (parent == null || child == null ||
 			!(parent instanceof Constraint) ||
 			!(child instanceof Component))
			return false;

		Object layoutParent = decodeEngine.getParent (parent);
		if (layoutParent == null)
			return false;

		Object containerParent = null;
		if (layoutParent instanceof Container)
		{
			containerParent = layoutParent;
			layoutParent = null;
		}
		else if (layoutParent instanceof LayoutManager)
		{
			containerParent = decodeEngine.getParent (layoutParent);
			if (!(containerParent instanceof Container))
				return false;
		}
		else
			return false;

		if (containerParent == null)
			return false;

		Container container = (Container)containerParent;

		String location = ((Constraint)parent).location;
		if (location == null)
			container.add ((Component)child);
		else
			container.add ((Component)child, location);

		return true;
	}
}
