/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.adder;

import java.awt.*;
import javax.swing.*;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Adder;

/**
 * Add two child components in order for JSplitPane.
 *
 * @cxdoc
 * The children must be two Component objects.  The first will be set as
 * the left (top) component and the second one will be set as the right
 * (bottom) component.
 *
 * @see javax.swing.JSplitPane
 * @author Heng Yuan
 * @version $Id: SplitPaneAdder.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.5.1
 */
public class SplitPaneAdder implements Adder
{
	public final static String KEY = "cookswing:splitpaneadder";

	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine)
	{
		if (parent == null || child == null ||
			!(parent instanceof JSplitPane) ||
			!(child instanceof Component))
			return false;
		Object v = ((JSplitPane)parent).getClientProperty (KEY);
		if (v == null)	// left component
		{
			((JSplitPane)parent).setLeftComponent ((Component)child);
			((JSplitPane)parent).putClientProperty (KEY, Boolean.TRUE);
		}
		else
		{
			((JSplitPane)parent).setRightComponent ((Component)child);
			((JSplitPane)parent).putClientProperty (KEY, null);
		}
		return true;
	}
}
