/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.adder;

import java.awt.*;
import javax.swing.*;

import cookxml.cookswing.helper.SpringConstraintHelper;
import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Adder;

/**
 * This adder is needed to add Spring or spring constraints to the container
 * ancestor.
 *
 * @see javax.swing.Spring
 * @see javax.swing.SpringLayout
 * @author Heng Yuan
 * @version $Id: SpringLayoutAdder.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.0
 */
public class SpringLayoutAdder implements Adder
{
	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine)
	{
		if (parent == null || child == null ||
			!(parent instanceof SpringLayout))
			return false;

		Object grandParent = decodeEngine.getParent (parent);
		if (grandParent == null ||
			!(grandParent instanceof Container))
			return false;
		Container container = (Container)grandParent;

		if (child instanceof Component)
		{
			container.add ((Component)child);
			return true;
		}

		if (child instanceof SpringConstraintHelper)
		{
			((SpringConstraintHelper)child).putConstraint ((SpringLayout)parent);
			return true;
		}

		return false;
	}
}
