/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.converter;

import java.awt.*;
import java.lang.reflect.Field;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.ConverterException;
import cookxml.core.interfaces.Converter;

/**
 * Convert a string name into the predefined cursor, without the * <code>_CURSOR</code> suffix
 * (e.g "HAND" would be converted to a hand cursor).
 * 
 * @cxdoc
 * One of the cursor names defined in java.awt.Cursor without the <code>_CURSOR</code>
 * suffix (e.g "HAND" would be converted to a hand cursor).
 *
 * @author Heng Yuan
 * @version $Id: CursorConverter.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.0
 */
public class CursorConverter implements Converter
{
	public Object convert (String value, DecodeEngine decodeEngine) throws Exception
	{
		// first check if it is a pre-defined color value
		Field field = Cursor.class.getField (value.toUpperCase () + "_CURSOR");
		if (field != null)
		{
			String str = field.get (null).toString ();
			return new Cursor (Integer.parseInt (str));
		}
		throw new ConverterException (decodeEngine, null, this, value);
	}
}
