/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.converter;

import java.awt.*;
import java.util.StringTokenizer;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Converter;

/**
 * Convert a string in "# #", "#,#" or "#x#" format into a dimension object.
 *
 * @cxdoc
 * "<code># #</code>", "<code>#,#</code>" or "<code>#x#</code>" format.
 * to specify the width, then height of the dimension.
 *
 * @author Heng Yuan
 * @version $Id: DimensionConverter.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.0
 */
public class DimensionConverter implements Converter
{
	public Object convert (String value, DecodeEngine decodeEngine)
	{
		StringTokenizer tokenizer = new StringTokenizer (value, ",x ");
		String widthStr = tokenizer.nextToken ();
		String heightStr = tokenizer.nextToken ();
		return new Dimension (Integer.parseInt (widthStr), Integer.parseInt (heightStr));
	}
}
