/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.converter;

import java.awt.*;
import java.util.StringTokenizer;
import javax.swing.*;

import cookxml.cookswing.CookSwingLib;
import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Converter;

/**
 * Convert a string representation into a Font.  The format is
 * "fontname,style,size".  For example, "monospace,bold italic,12".
 *
 * @cxdoc
 * There are two valid types of values:
 * <ul>
 *     <li>"<code>fontname,style,size</code>". For example, "<code>monospace,bold italic,12</code>".
 *     <li><code>ui:<i>key</i></code> for fonts that can be retrieved from UIManager
 *			with the given key.</li>
 * </ul>
 *
 * @author Heng Yuan
 * @version $Id: FontConverter.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.0
 */
public class FontConverter implements Converter
{
	public Object convert (String value, DecodeEngine decodeEngine)
	{
		// check if it is a UIManager font name.  According to dmoebius's suggestion
		if (value.startsWith (CookSwingLib.UI_PREFIX))
		{
			try
			{
				Font font = UIManager.getFont (value.substring (CookSwingLib.UI_PREFIX.length ()));
				if (font != null)
					return font;
			}
			catch (Exception ex)
			{
			}
		}

		StringTokenizer tokenizer = new StringTokenizer (value, ",");
		String fontName = tokenizer.nextToken ().trim ();
		String styleStr = tokenizer.nextToken ().trim ().toLowerCase ();
		String sizeStr = tokenizer.nextToken ().trim ();

		int type = Font.PLAIN;
		if (styleStr.indexOf ("bold") >= 0)
			type = Font.BOLD;
		if (styleStr.indexOf ("italic") >= 0)
			type |= Font.ITALIC;

		if (fontName.length () == 0)
			fontName = null;

		return new Font (fontName, type, Integer.parseInt (sizeStr));
	}
}
