/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.creator;

import javax.swing.*;

import org.w3c.dom.Element;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.CreatorException;
import cookxml.core.interfaces.Creator;

/**
 * This creator creates JSpinner.DefaultEditor class objects.
 *
 * @see javax.swing.JSpinner.DefaultEditor
 * @author Heng Yuan
 * @version $Id: SpinnerEditorCreator.java 233 2007-06-06 08:08:49Z coconut $
 * @since CookSwing 1.0
 */
public class SpinnerEditorCreator implements Creator
{
	public final static String FORMAT_ATTR = "format";

	private Class m_editorClass;

	public SpinnerEditorCreator (Class editorClass)
	{
		m_editorClass = editorClass;
	}

	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine)
	{
		if (parentObj == null ||
			!(parentObj instanceof JSpinner))
			return null;

		if (m_editorClass == JSpinner.DefaultEditor.class)
			return new JSpinner.DefaultEditor ((JSpinner)parentObj);
		if (m_editorClass == JSpinner.ListEditor.class)
			return new JSpinner.ListEditor ((JSpinner)parentObj);

		String format = elm.getAttribute (FORMAT_ATTR);
		if (format != null && format.length () == 0)
			format = null;

		if (m_editorClass == JSpinner.DateEditor.class)
		{
			if (format == null)
				return new JSpinner.DateEditor ((JSpinner)parentObj);
			return new JSpinner.DateEditor ((JSpinner)parentObj, format);
		}
		if (m_editorClass == JSpinner.NumberEditor.class)
		{
			if (format == null)
				return new JSpinner.NumberEditor ((JSpinner)parentObj);
			return new JSpinner.NumberEditor ((JSpinner)parentObj, format);
		}
        throw new CreatorException (decodeEngine, null, this, parentNS, parentTag, elm, parentObj);
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine)
	{
		return obj;
	}
}
