/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.creator;

import javax.swing.*;

import org.w3c.dom.Element;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Creator;

/**
 * This creator does not create, but rather retrieve the JTableHeader from the table parent.
 * This main purose of this class is to allow one to manipulate the table header.
 *
 * @cxdoc
 * This tag does not actually create a new JTableHeader instance.  Instead, it retrieves
 * an instance from the parent tag {@tag table}.
 *
 * @cxexample
 * <codeblock type="xml">
 * 	<table>
 * 		<tableheader reorderingallowed="false"/>
 * 	</table>
 * </codeblock>
 *
 * @see javax.swing.table.JTableHeader
 * @author Heng Yuan
 * @version $Id: TableHeaderCreator.java 251 2007-06-08 00:19:35Z coconut $
 * @since CookSwing 1.0
 */
public class TableHeaderCreator implements Creator
{
	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine)
	{
		if (parentObj == null ||
			!(parentObj instanceof JTable))
			return null;
		decodeEngine.setDoAdd (false);
		return ((JTable)parentObj).getTableHeader ();
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine)
	{
		return obj;
	}
}
