/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.helper;

import java.awt.*;
import javax.swing.*;
import javax.swing.border.BevelBorder;
import javax.swing.border.SoftBevelBorder;

import cookxml.core.interfaces.Helper;

/**
 * Helper class for creating a BevelBorder.
 *
 * @cxhelper javax.swing.border.BevelBorder
 * 
 * @author Heng Yuan
 * @version $Id: BevelBorderHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookSwing 1.0
 */
public class BevelBorderHelper implements Helper
{
	/** If true, a bevel border with softened corner would be created. */
	public boolean soft;
	/** RAISED or LOWERED border. */
	public int type;
	public Color highlight;
	public Color shadow;
	public Color highlightOuter;
	public Color highlightInner;
	public Color shadowOuter;
	public Color shadowInner;

	public BevelBorderHelper ()
	{
		type = -1;
	}

	public Object getFinalObject ()
	{
		if (type == -1)
			return null;

		if (highlight != null && shadow != null)
		{
			if (soft)
				return new SoftBevelBorder (type, highlight, shadow);
			return BorderFactory.createBevelBorder (type, highlight, shadow);
		}

		if (highlightOuter != null && highlightInner != null &&
		    shadowOuter != null && shadowInner != null)
		{
			if (soft)
				return new SoftBevelBorder (type, highlightOuter, highlightInner, shadowOuter, shadowInner);
			return BorderFactory.createBevelBorder (type, highlightOuter, highlightInner, shadowOuter, shadowInner);
		}

		if (type == BevelBorder.RAISED)
		{
			if (soft)
				return new SoftBevelBorder (type);
			return BorderFactory.createRaisedBevelBorder ();
		}
		else if (type == BevelBorder.LOWERED)
		{
			if (soft)
				return new SoftBevelBorder (type);
			return BorderFactory.createLoweredBevelBorder ();
		}
		return null;
	}
}
