/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.helper;

import java.util.Iterator;
import java.util.LinkedList;
import javax.swing.*;
import javax.swing.border.Border;

import cookxml.core.interfaces.Helper;

/**
 * This BorderHelper class can compute and generates a CompoundBorder from a list of
 * borders.
 *
 * @cxhelper javax.swing.border.CompoundBorder
 * 
 * @author Heng Yuan
 * @version $Id: CompoundBorderHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookSwing 1.0
 */
public class CompoundBorderHelper implements Helper
{
	private final LinkedList m_borderList = new LinkedList ();

	public Object getFinalObject ()
	{
		LinkedList borderList = m_borderList;
		int size = borderList.size ();
		if (size == 0)
			return BorderFactory.createCompoundBorder ();
		if (size == 1)
			return (Border)borderList.getFirst ();
		Iterator iter = borderList.iterator ();
		return createBorder ((Border)iter.next (), iter);
	}

	private Border createBorder (Border outsideBorder, Iterator iter)
	{
		if (!iter.hasNext ())
			return outsideBorder;
		return BorderFactory.createCompoundBorder (outsideBorder, createBorder ((Border)iter.next (), iter));
	}

	/**
	 * Add the border to the compound border.
	 *
	 * @param	border
	 * 			the border to be added.
	 */
	public void add (Border border)
	{
		if (border != null)
			m_borderList.add (border);
	}
}
