/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.helper;

import javax.swing.*;

import cookxml.core.interfaces.Helper;

/**
 * Helper class for constructing a KeyStroke object.
 *
 * @cxhelper javax.swing.KeyStroke
 *
 * @author Heng Yuan
 * @version $Id: KeyStrokeHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookSwing 1.0
 */
public class KeyStrokeHelper implements Helper
{
	/** The character representation of the key. */
	public Character keyChar;
	/** The VK_ name of the key. */
	public Integer keyCode;
	/** Optional and can be CTRL_MASK, SHIFT_MASK, ALT_MASK or META_MASK. */
	public Integer modifiers;
	/** Which or not the key stroke on key release. */
	public Boolean onKeyRelease;
	/** A string representation of the KeyStroke. */
	public String string;

	/**
	 * returns the KeyStroke from the helper object.
	 * @return the KeyStroke from the helper object.
	 */
	public Object getFinalObject ()
	{
		if (keyChar != null)
		{
			if (modifiers != null)
				return KeyStroke.getKeyStroke (keyChar, modifiers.intValue ());
			return KeyStroke.getKeyStroke (keyChar.charValue ());
		}
		if (keyCode != null && modifiers != null)
		{
			if (onKeyRelease != null)
				return KeyStroke.getKeyStroke (keyCode.intValue (), modifiers.intValue (), onKeyRelease.booleanValue ());
			return KeyStroke.getKeyStroke (keyCode.intValue (), modifiers.intValue ());
		}
		if (string != null)
			return KeyStroke.getKeyStroke (string);
		return null;
	}
}
