/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.helper;

import java.awt.*;
import java.util.Iterator;
import java.util.LinkedList;
import javax.swing.*;

import cookxml.core.interfaces.NoAdd;

/**
 * Helper class for constructing a Spring object.
 *
 * @cxhelper javax.swing.Spring
 *
 * @author Heng Yuan
 * @version $Id: SpringHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookSwing 1.0
 */
public class SpringHelper implements NoAdd
{
	/** get the maximum spring of the child springs. */
	public static String OP_MAX = "max";
	/** get the difference of the child springs. */
	public static String OP_MINUS = "-";
	/** get the sum spring of the child springs. */
	public static String OP_SUM = "sum";

	/** to create a rigid spring of the fixed size. */
	public Integer size;
	/** to create a flexiable spring with the minimum size. */
	public Integer min;
	/** to create a flexiable spring with the maximum size. */
	public Integer max;
	/** to create a flexiable spring with the preferred size. */
	public Integer pref;

	/** get a spring from the component child. The value can be either "width", "height", "x" or "y". */
	public String get;

	private Component m_comp;

	/**
	 * The math operation that to be done to the child spring, which can be "max", "sum", and "-".
	 * @see #OP_MAX
	 * @see #OP_MINUS
	 * @see #OP_SUM
	 */
	public String op;

	private LinkedList m_springList = new LinkedList ();

	public Spring getSpring (SpringLayout layout)
	{
		if (size != null)
			return Spring.constant (size.intValue ());

		if (min != null && max != null && pref != null)
			return Spring.constant (min.intValue (), pref.intValue (), max.intValue ());

		if (m_comp != null && get != null)
		{
			if ("width".equalsIgnoreCase (get))
				return layout.getConstraints (m_comp).getWidth ();
			if ("height".equalsIgnoreCase (get))
				return layout.getConstraints (m_comp).getHeight ();
			if ("x".equalsIgnoreCase (get))
				return layout.getConstraints (m_comp).getX ();
			if ("y".equalsIgnoreCase (get))
				return layout.getConstraints (m_comp).getY ();
			//return layout.getConstraint (m_edge, m_comp);
		}

		LinkedList springList = m_springList;

		if (op != null && springList.size () > 0)
		{
			if (OP_MAX.equalsIgnoreCase (op))
			{
				Spring max = Spring.constant (0);
				for (Iterator iter = springList.iterator (); iter.hasNext ();)
					max = Spring.max (max, (Spring)iter.next ());
				return max;
			}
			if (OP_SUM.equalsIgnoreCase (op))
			{
				Iterator iter = springList.iterator ();
				Spring sum = (Spring)iter.next ();
				for (; iter.hasNext ();)
				{
					Spring s = (Spring)iter.next ();
					sum = Spring.sum (sum, s);
				}
				return sum;
			}
			if (OP_MINUS.equalsIgnoreCase (op))
			{
				if (springList.size () == 0)
					return Spring.constant (0);
				Iterator iter = springList.iterator ();
				Spring first = (Spring)iter.next ();
				return Spring.minus (first);
			}
		}
		return Spring.constant (0);
	}

	/**
	 * Add the spring constraint into consideration.
	 *
	 * @param	s
	 * 			the spring constraint.
	 */
	public void add (Spring s)
	{
		m_springList.add (s);
	}

	/**
	 * Use the component's information to obtain the constraint.
	 *
	 * @param	c
	 * 			the child component.
	 */
	public void add (Component c)
	{
		m_comp = c;
	}
}
