/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.helper;

import java.util.Locale;
import javax.swing.*;

import cookxml.core.interfaces.Helper;

/**
 * Helper class for constructing a String object.
 *
 * @cxdoc
 * This tag is used to create a String object.
 * <p>
 * If the attribute "<code>ui</code>", then the UIManager is called
 * to retrieve the String using the ui key in the "<code>locale</code>"
 * specified.
 * <p>
 * <b>Example</b>:
 * <codeblock type="xml">
 * 	<vector>
 * 		<string text="this is a test."/>
 * 		<string ui="OptionPane.okButtonText"/>
 * 	</vector>
 * </codeblock>
 *
 * @cxhelper java.lang.String
 *
 * @author Heng Yuan
 * @version $Id: StringHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookSwing 1.0
 */
public class StringHelper implements Helper
{
	/** the string text. */
	public String text;

	/** the ui key used to look up the String in UIManager */
	public String ui;
	/** Local of the ui key.  If not specified, the default is used. */
	public Locale locale;

	public Object getFinalObject ()
	{
		if (text != null)
			return text;
		if (ui != null)
		{
			if (locale != null)
				return UIManager.getString (ui, locale);
			return UIManager.getString (ui);
		}
		return null;
	}
}
