/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.helper;

import javax.swing.*;

import cookxml.core.interfaces.NoAdd;

/**
 * Helper class for retrieving UIManager key values or setting the look & feel
 * @cxdoc
 * This tag is used to set the look-n-feel of the Swing components.
 * <p>
 * In general it should only be used once per application.  So this tag
 * should only be used immediately inside the frame tag.
 * <p>
 * <b>Example</b>:
 * <codeblock type="xml">
 * 	<frame title="Test">
 * 		<uimanager systemlookandfeel="true"/>
 * 	</frame>
 * </codeblock>
 *
 * @cxhelper javax.swing.UIManager
 *
 * @author Heng Yuan
 * @version $Id: UIManagerHelper.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookSwing 1.0
 */
public class UIManagerHelper implements NoAdd
{
	/**
	 * Set the current default look-n-feel using the given class name.
	 * 
	 * @param	className
	 *			the look-n-feel class name.
	 */
	public void setLookAndFeel (String className)
	{
		try
		{
			UIManager.setLookAndFeel (className);
		}
		catch (Exception ex)
		{
		}
	}

	/**
	 * If true, the system look-n-feel is installed, otherwise, the cross
	 * platform look-n-feel is installed.
	 *
	 * @param	b
	 *			whether or not to use the system look-n-feel.
	 */
	public void setSystemLookAndFeel (boolean b)
	{
		if (b)
			setLookAndFeel (UIManager.getSystemLookAndFeelClassName());
		else
			setLookAndFeel (UIManager.getCrossPlatformLookAndFeelClassName());
	}
}
