/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.setter;

import javax.swing.*;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.SetterException;
import cookxml.core.interfaces.Setter;

/**
 * This setter provides the functionality of setting a JFrame or JDialog to be decorated.
 *
 * @cxattr	boolean
 * 			If true, then set the dialog/frame to be decorated.
 * 
 * @see javax.swing.JDialog
 * @see javax.swing.JFrame
 * @author Heng Yuan
 * @version $Id: DecoratedWindowSetter.java 219 2007-06-06 06:40:39Z coconut $
 * @since CookSwing 1.0
 */
public class DecoratedWindowSetter implements Setter
{
	public void setAttribute (String ns, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine) throws SetterException
	{
		if (value == null || !(value instanceof String))
			return;
		boolean b = Boolean.valueOf ((String)value).booleanValue ();
		if (obj instanceof JDialog)
		{
			JDialog dialog = ((JDialog)obj);
			dialog.setUndecorated (true);
			if (b)
				dialog.getRootPane().setWindowDecorationStyle(JRootPane.PLAIN_DIALOG);
		}
		else if (obj instanceof JFrame)
		{
			JFrame frame = ((JFrame)obj);
			frame.setUndecorated (true);
			if (b)
				frame.getRootPane().setWindowDecorationStyle(JRootPane.FRAME);
		}
		else
			throw new SetterException (decodeEngine, null, this, ns, tag, attrNS, attr, obj, value);
	}
}
