/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.setter;

import java.awt.*;
import java.util.IdentityHashMap;
import java.util.Iterator;
import java.util.Map;
import javax.swing.*;

import cookxml.core.DecodeEngine;
import cookxml.core.converter.ObjectConverter;
import cookxml.core.interfaces.CleanupHook;
import cookxml.core.interfaces.Setter;

/**
 * This setter provides the forward id/variable lookup, using the new CleanupHook feature
 * in CookXml 2.5, to call JLabel's setLabelFor
 *
 * @cxsetter	java.awt.Component
 * 				Set the component this is labelling.
 *
 * @author Heng Yuan
 * @version $Id: LabelForSetter.java 250 2007-06-07 07:20:37Z coconut $
 * @since CookSwing 1.4
 */
public class LabelForSetter implements Setter
{
	private final static String PROP_LABEL_FOR = "labelFor";

	private final CleanupHook m_labelForHook = new CleanupHook ()
	{
		public void cleanup (DecodeEngine decodeEngine)
		{
			Map map = (Map)decodeEngine.getProperty (PROP_LABEL_FOR);
			if (map == null)
				return;

			for (Iterator iter = map.entrySet ().iterator (); iter.hasNext ();)
			{
				try
				{
					Map.Entry entry = (Map.Entry)iter.next ();
					JLabel label = (JLabel)entry.getKey ();
					Component comp = (Component)ObjectConverter.getInstance ().convert ((String)entry.getValue (), decodeEngine);
					label.setLabelFor (comp);
				}
				catch (Exception ex)
				{
				}
			}
		}
	};

	public void setAttribute (String ns, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine)
	{
		Object comp = null;
		try
		{
			comp = ObjectConverter.getInstance ().convert ((String)value, decodeEngine);
		}
		catch (Exception ex)
		{
		}

		if (comp == null)
		{
			Map map = (Map)decodeEngine.getProperty (PROP_LABEL_FOR);
			if (map == null)
			{
				map = new IdentityHashMap ();
				decodeEngine.setProperty (PROP_LABEL_FOR, map);
			}
			map.put (obj, value);
			decodeEngine.addCleanupHook (m_labelForHook);
			return;
		}

		// force CastException if type not match
		((JLabel)obj).setLabelFor ((Component)comp);
	}
}
