/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.setter;

import javax.swing.*;
import javax.swing.event.ListSelectionListener;

import cookxml.core.DecodeEngine;
import cookxml.core.doclet.DocletActionReporter;
import cookxml.core.exception.SetterException;
import cookxml.core.interfaces.Setter;
import cookxml.core.interfaces.TagLibrary;

/**
 * @author Heng Yuan
 * @version $Id: ListSelectionListenerSetter.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookSwing 1.3
 */
public class ListSelectionListenerSetter implements Setter, DocletActionReporter
{
	public void setAttribute (String ns, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine) throws SetterException
	{
		if (value == null || (!(obj instanceof JTable) && !(obj instanceof JList)))
			throw new SetterException (decodeEngine, null, this, ns, tag, attrNS, attr, obj, value);

		try
		{
			ListSelectionListener listener = null;
			if (value instanceof ListSelectionListener)
				listener = (ListSelectionListener)value;
			else if (value instanceof String)
			{
				Object o = decodeEngine.getVariable ((String)value);
				if (o instanceof ListSelectionListener)
					listener = (ListSelectionListener)o;
			}
			if (listener != null)
			{
				ListSelectionModel selectionModel = null;
				if (obj instanceof JTable)
					selectionModel = ((JTable)obj).getSelectionModel ();
				if (selectionModel != null)
				{
					selectionModel.addListSelectionListener (listener);
					return;
				}
			}
		}
		catch (Exception ex)
		{
			throw new SetterException (decodeEngine, ex, this, ns, tag, attrNS, attr, obj, value);
		}
		throw new SetterException (decodeEngine, null, this, ns, tag, attrNS, attr, obj, value);
	}

	public Object[] getActions (TagLibrary tagLibrary, String tagNS, String tag, String attrNS, String attr, Class cl)
	{
		if (cl == null)
			return new Object[0];
		if (JTable.class.isAssignableFrom (cl))
		{
			try
			{
				return new Object[]{ ListSelectionModel.class.getMethod ("addListSelectionListener", new Class[]{ ListSelectionListener.class }) };
			}
			catch (Exception ex)
			{
			}
		}
		return new Object[0];
	}
}
