/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswing.util;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.Iterator;
import java.util.LinkedList;
import javax.swing.*;

/**
 * This listener is used to synchronize button states.
 *
 * @see cookxml.cookswing.helper.SyncButtonStateHelper
 * @author Heng Yuan
 * @version $Id: SyncButtonStateListener.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookSwing 1.0
 */
public class SyncButtonStateListener implements PropertyChangeListener, ItemListener
{
	private LinkedList m_btnList;

	private SyncButtonStateListener (LinkedList btnList)
	{
		m_btnList = btnList;
	}

	public void itemStateChanged (ItemEvent e)
	{
		AbstractButton btn = (AbstractButton)e.getSource ();
		boolean b = btn.isSelected ();
		for (Iterator iter = m_btnList.iterator (); iter.hasNext ();)
		{
			AbstractButton button = (AbstractButton)iter.next ();
			if (button == btn || button.isSelected ()  == b)
				continue;
			button.setSelected (b);
		}
	}

	public void propertyChange (PropertyChangeEvent e)
	{
		AbstractButton btn = (AbstractButton)e.getSource ();
		boolean b = btn.isEnabled ();
		for (Iterator iter = m_btnList.iterator (); iter.hasNext ();)
		{
			AbstractButton button = (AbstractButton)iter.next ();
			if (button == btn || button.isEnabled ()  == b)
				continue;
			button.setEnabled (b);
		}
	}

	public static void syncButtons (LinkedList btnList)
	{
		SyncButtonStateListener listener = new SyncButtonStateListener (btnList);
		for (Iterator iter = btnList.iterator (); iter.hasNext ();)
		{
			AbstractButton button = (AbstractButton)iter.next ();
			button.addItemListener (listener);
			button.addPropertyChangeListener ("enabled", listener);
		}
	}
}
