/*
 */
package examples.cookswing;

import java.awt.*;
import java.awt.event.*;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.File;
import java.util.HashMap;
import java.util.Map;
import javax.swing.*;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

import cookxml.cookswing.CookSwing;
import cookxml.core.util.TextUtils;

import examples.util.XmlToHtmlConverter;

/**
 * This class serves two purposes.  One is to demonstrate the pre-built GUI xml form files.
 * Another is to preview user's own XML form files.
 * @author Heng Yuan
 */
public class CookSwingDemo
{
	public Container rootFrame;
	public JFileChooser openFileChooser;
	public JPanel swingPane;
	public JEditorPane xmlPane;
	public JLabel statusBar;
	public JDialog aboutDialog;

	public String msgConfirmExit;
	public String msgInvalidXmlFile;
	public String msgFileOpened;
	public String msgExitCanceled;
	public String msgCopyright;

	public Map systemProperties = readSystemProperties ();

	public PropertyChangeListener valuePropertyChangeListener = new PropertyChangeListener ()
	{
		public void propertyChange (PropertyChangeEvent e)
		{
			setStatus ("new value: " + e.getNewValue ());
		}
	};

	public ActionListener disposeListener = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			if (aboutDialog != null)
				aboutDialog.dispose ();
		}
	};

	public WindowListener frameListener = new WindowAdapter ()
	{
		public void windowClosing (WindowEvent e)
		{
			doExit ();
		}
	};

	public ActionListener exitAction = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			doExit ();
		}
	};

	public ActionListener openAction = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			doOpen ();
		}
	};

	public ActionListener comboBoxAction = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			JComboBox box = (JComboBox)e.getSource ();
			String name = (String)box.getSelectedItem ();
			doOpenXml ("examples/cookswing/xml/" + name);
		}
	};

	public ActionListener buttonAction = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			setStatus (e.getActionCommand ());
		}
	};

	public ActionListener aboutAction = new ActionListener ()
	{
		public void actionPerformed (ActionEvent e)
		{
			doAbout ();
		}
	};

	public ListSelectionListener listSelectionAction = new ListSelectionListener ()
	{
		public void valueChanged (ListSelectionEvent e)
		{
			if (e.getValueIsAdjusting ())
				return;
			setStatus ("selection made...");
		}
	};

	public void doAbout ()
	{
		if (aboutDialog == null)
			JOptionPane.showMessageDialog (rootFrame, msgCopyright);
		else
		{
			aboutDialog.setLocationRelativeTo (rootFrame);
			aboutDialog.setVisible (true);
		}
	}

	public void doOpen ()
	{
		openFileChooser.setCurrentDirectory (new File (System.getProperty ("user.dir")));
		int response = openFileChooser.showOpenDialog (rootFrame);
		if (response == JFileChooser.APPROVE_OPTION)
		{
			File file = openFileChooser.getSelectedFile ();
			if (file == null)
				return;
			doOpenXml (file.toString ());
		}
	}

	public void doOpenXml (String input)
	{
		CookSwing cookSwing = new CookSwing (this);		// just to for hooking up buttonAction
		Container container = cookSwing.render (input);
		if (container == null)
		{
			setStatus (msgInvalidXmlFile + input);
			return;
		}
		if (container instanceof JFrame ||
			container instanceof JDialog)
		{
			container.setVisible (true);
		}
		else
		{
			swingPane.removeAll ();
			swingPane.add (container);
		}

		setStatus (msgFileOpened + input);

		String html;
		try
		{
			html = XmlToHtmlConverter.convert ("", TextUtils.readText (input));
		}
		catch (Exception ex)
		{
			html = "<html><body><h1>Error reading XML code.</h1></body></html>";
		}
		xmlPane.setText (html);
	}

	public void doExit ()
	{
		int response = JOptionPane.showConfirmDialog (rootFrame, msgConfirmExit,
													  UIManager.getString("OptionPane.titleText"),
													  JOptionPane.OK_CANCEL_OPTION);
		if (response == JOptionPane.OK_OPTION)
			System.exit (0);
		else
			setStatus (msgExitCanceled);
	}

	public void setStatus (String text)
	{
		statusBar.setText (text);
	}

	private static String[] s_propertyKeys =
			{
				"java.version",
				"java.vender",
				"java.vendor.url",
				"java.home",
				"java.vm.specification.version",
				"java.vm.specification.vendor",
				"java.vm.specification.name",
				"java.vm.version",
				"java.vm.vendor",
				"java.vm.name",
				"java.specification.version",
				"java.specification.vendor",
				"java.specification.name",
				"java.class.version",
				"java.class.path",
				"java.library.path",
				"java.io.tmpdir",
				"java.compiler",
				"java.ext.dirs",
				"os.name",
				"os.arch",
				"os.version",
				"file.separator",
				"path.separator",
				"line.separator",
				"user.name",
				"user.home",
				"user.dir"
			};

	private static Map readSystemProperties ()
	{
		try
		{
			return System.getProperties ();
		}
		catch (Exception ex)
		{
			// there is a security manager, so we can try to get it using getProperty instead
			Map properties = new HashMap ();
			String[] propertyKeys = s_propertyKeys;
			for (int i = 0; i < propertyKeys.length; ++i)
			{
				try
				{
					String key = propertyKeys[i];
					String value = System.getProperty (key);
					if (value == null)
						continue;
					properties.put (key, value);
				}
				catch (Exception ex2)
				{
				}
			}
			return properties;
		}
	}

	public static void main (String[] args)
	{
		CookSwing cookSwing = new CookSwing (new CookSwingDemo ());
		cookSwing.render ("examples/cookswing/xml/cookswingdemo.xml").setVisible (true);
	}
}
