/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.adder;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.CoolItem;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.AdderException;
import cookxml.core.interfaces.Adder;

/**
 * This Adder add a control to the CoolItem and set the minimum and preferred size
 * of the CoolItem to the preferred size of the control.
 *
 * @since CookSwt 1.0
 * @author Heng Yuan
 */
public class CoolItemAdder implements Adder
{
	private final static Adder s_instance = new CoolItemAdder ();

	public static Adder getInstance ()
	{
		return s_instance;
	}

	private CoolItemAdder ()
	{
	}

	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine) throws AdderException, Exception
	{
		if (parent == null || child == null ||
			!(parent instanceof CoolItem) ||
			!(child instanceof Control))
			return false;

		Control control = (Control) child;
		CoolItem item = (CoolItem) parent;
		Point size = control.computeSize (SWT.DEFAULT, SWT.DEFAULT);
		item.setPreferredSize (size);
		item.setMinimumSize (size);
		item.setControl (control);
		return true;
	}
}
