/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.adder;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.ToolItem;

import cookxml.cookswt.util.SwtUtils;
import cookxml.core.DecodeEngine;
import cookxml.core.exception.AdderException;
import cookxml.core.interfaces.Adder;

/**
 * This is a adder that adds a drop down menu to a drop down tool item.
 *
 * @since CookSwt 1.0
 * @author Heng Yuan
 */
public class DropDownMenuAdder implements Adder
{
	private final static Adder s_instance = new DropDownMenuAdder ();

	public static Adder getInstance ()
	{
		return s_instance;
	}

	private DropDownMenuAdder ()
	{
	}

	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine) throws AdderException, Exception
	{
		if (parent == null || child == null ||
			!(parent instanceof ToolItem) ||
			(((ToolItem) parent).getStyle () & SWT.DROP_DOWN) == 0 ||
			!(child instanceof Menu))
			return false;

		SwtUtils.attachToolItemDropDownMenu ((ToolItem) parent, (Menu) child);
		return true;
	}
}
