/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.adder;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.ExpandItem;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.AdderException;
import cookxml.core.interfaces.Adder;

/**
 * This Adder add a control to the ExpandItem and set the height of the
 * ExpandItem to the preferred height of the control.
 *
 * @author Heng Yuan
 * @since CookSwt 1.2
 */
public class ExpandItemAdder implements Adder
{
	private final static Adder s_instance = new ExpandItemAdder ();

	public static Adder getInstance ()
	{
		return ExpandItemAdder.s_instance;
	}

	private ExpandItemAdder ()
	{
	}

	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine) throws AdderException, Exception
	{
		if (parent == null || child == null ||
		    !(parent instanceof ExpandItem) ||
		    !(child instanceof Control))
			return false;

		Control control = (Control)child;
		ExpandItem item = (ExpandItem)parent;
		Point size = control.computeSize (SWT.DEFAULT, SWT.DEFAULT);
		item.setHeight (size.y);
		item.setControl (control);
		return true;
	}
}
