/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.adder;

import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableItem;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.AdderException;
import cookxml.core.interfaces.Adder;

/**
 * This Adder add a control to the CoolItem and set the minimum and preferred size
 * of the CoolItem to the preferred size of the control.
 *
 * @since CookSwt 1.0
 * @author Heng Yuan
 */
public class TableAdder implements Adder
{
	private final static Adder s_instance = new TableAdder ();

	public static Adder getInstance ()
	{
		return s_instance;
	}

	private TableAdder ()
	{
	}

	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine) throws AdderException, Exception
	{
		if (parent == null || child == null ||
			!(parent instanceof Table) ||
			!(child instanceof Map))
			return false;
		Table table = (Table) parent;
		Map map = (Map) child;
		Set keySet = new TreeSet (map.keySet ());
		for (Iterator iter = keySet.iterator (); iter.hasNext ();)
		{
			Object key = iter.next ();
			Object value = map.get (key);
			TableItem tableItem = new TableItem (table, SWT.NONE);
			if (key instanceof Image)
				tableItem.setImage (0, (Image) key);
			else if (key != null)
				tableItem.setText (0, key.toString ());
			if (value instanceof Image)
				tableItem.setImage (1, (Image) value);
			else if (value != null)
				tableItem.setText (1, value.toString ());
		}
		return true;
	}
}
