/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.converter;

import java.lang.reflect.Field;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.widgets.Display;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.ConverterException;
import cookxml.core.interfaces.Converter;

/**
 * Convert a hex representation in "#rrggbb", "rrggbb", or names predefined in Color.
 *
 * @see Color
 * @author Heng Yuan
 * @version $Id: ColorConverter.java 222 2007-06-06 06:44:31Z coconut $
 * @since CookSwt 1.0
 */
public class ColorConverter implements Converter
{
	private final static ColorConverter s_instance = new ColorConverter ();

	public static ColorConverter getInstance ()
	{
		return s_instance;
	}

	private ColorConverter ()
	{
	}

	public Object convert (String value, DecodeEngine decodeEngine) throws ConverterException
	{
		Color color = getColor (value);
		if (color != null)
			return color;
		throw new ConverterException (decodeEngine, null, this, value);
	}

	public static Color getColor (String value)
	{
		if (value == null)
			return null;
		try
		{
			String colorName = value.toUpperCase ();
			if (colorName.indexOf ("COLOR_") != 0)
				colorName = "COLOR_" + value;
			Field colorField = SWT.class.getField (colorName);
			if (colorField != null)
			{
				int id = colorField.getInt (null);
				return Display.getCurrent ().getSystemColor (id);
			}
		}
		catch (Exception ex)
		{
		}
		String colorVal = value;
		if (colorVal.startsWith ("#"))
			colorVal = colorVal.substring (1);
		try
		{
			int hexVal = Integer.parseInt (colorVal, 16);
			return new Color (Display.getCurrent (), (hexVal >> 16) & 0xff, (hexVal >> 8) & 0xff, hexVal & 0xff);
		}
		catch (Exception ex)
		{
		}
		return null;
	}
}
