/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.converter;

import java.lang.reflect.Field;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.ConverterException;
import cookxml.core.interfaces.Converter;

/**
 * The name of a predefined cursor, with or without the <tt>CURSOR_</tt> prefix.
 *
 * @see org.eclipse.swt.graphics.Cursor
 * @author Heng Yuan
 * @version $Id: CursorConverter.java 257 2007-06-10 07:10:05Z coconut $
 * @since CookSwt 1.0
 */
public class CursorConverter implements Converter
{
	private final static CursorConverter s_instance = new CursorConverter ();

	public static CursorConverter getInstance ()
	{
		return s_instance;
	}

	private CursorConverter ()
	{
	}

	public Object convert (String value, DecodeEngine decodeEngine) throws ConverterException
	{
		try
		{
			value = value.toUpperCase ();
			if (value.indexOf ("CURSOR_") != 0)
				value = "CURSOR_" + value;
			Field colorField = SWT.class.getField (value);
			if (colorField != null)
			{
				int id = colorField.getInt (null);
				return Display.getCurrent ().getSystemCursor (id);
			}
		}
		catch (Exception ex)
		{
			throw new ConverterException (decodeEngine, ex, this, value);
		}
		throw new ConverterException (decodeEngine, null, this, value);
	}
}
