/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.converter;

import java.lang.reflect.Field;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Display;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.ConverterException;
import cookxml.core.interfaces.Converter;

/**
 * Convert a string into an Image object.  The resource is looked up using ClassLoader.
 *
 * @see Image
 * @see ClassLoader
 * @author Heng Yuan
 * @version $Id: ImageConverter.java 222 2007-06-06 06:44:31Z coconut $
 * @since CookSwt 1.0
 */
public class ImageConverter implements Converter
{
	private final static ImageConverter s_instance = new ImageConverter ();

	public static ImageConverter getInstance ()
	{
		return s_instance;
	}

	private ImageConverter ()
	{
	}

	public Object convert (String value, DecodeEngine decodeEngine) throws ConverterException
	{
		try
		{
			String imageName = value.toUpperCase ().trim ();
			if (!imageName.startsWith ("ICON_"))
				imageName = "ICON_" + value;
			Field imageField = SWT.class.getField (imageName);
			if (imageField != null)
			{
				int id = imageField.getInt (null);
				return Display.getCurrent ().getSystemImage (id);
			}
		}
		catch (Exception ex)
		{
		}

		try
		{
			return new Image (Display.getCurrent (), decodeEngine.getCookXml ().getClassLoader ().getResourceAsStream (value));
		}
		catch (Exception ex)
		{
			throw new ConverterException (decodeEngine, ex, this, value);
		}
	}
}
