/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.creator;

import java.lang.reflect.Field;
import java.util.StringTokenizer;

import org.eclipse.swt.layout.GridData;
import org.w3c.dom.Element;

import cookxml.cookswt.exception.BadStyleException;
import cookxml.core.DecodeEngine;
import cookxml.core.exception.CookXmlException;
import cookxml.core.interfaces.Creator;

/**
 * @see GridData
 * @author Heng Yuan
 * @version $Id: GridDataCreator.java 237 2007-06-06 15:15:57Z coconut $
 * @since CookSwt 1.0
 */
public class GridDataCreator implements Creator
{
	public static String STYLE_ATTR = "style";

	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine)
	{
		int style = getStyle (elm, decodeEngine);
		if (style == 0)
			return new GridData ();
		return new GridData (style);
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine)
	{
		return obj;
	}

	public static int getStyle (Element elm, DecodeEngine decodeEngine) throws CookXmlException
	{
		int returnVal = 0;

		try
		{
			String value = elm.getAttribute (STYLE_ATTR);
			if (value == null || value.length () == 0)
				return returnVal;
			StringTokenizer tokenizer = new StringTokenizer (value, "| ");
			do
			{
				String tok = tokenizer.nextToken ();
				Field field = GridData.class.getField (tok);
				returnVal |= field.getInt (null);
			}
			while (tokenizer.hasMoreElements ());
		}
		catch (Exception ex)
		{
			decodeEngine.handleException (null, new BadStyleException (GridData.class, elm.getAttribute (STYLE_ATTR)));
		}
		return returnVal;
	}
}
