/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.creator;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.w3c.dom.Element;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.CreatorException;
import cookxml.core.interfaces.Creator;

/**
 * @see Menu
 * @author Heng Yuan
 * @version $Id: MenuSplitCreator.java 237 2007-06-06 15:15:57Z coconut $
 * @since CookSwt 1.0
 */
public class MenuSplitCreator implements Creator
{
	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine)
	{
		// search the parent tree and try to find the parent that is a widget
		Object widgetParent = parentObj;
		while (widgetParent != null &&
			   !(widgetParent instanceof Menu))
			widgetParent = decodeEngine.getParent (widgetParent);

		if (widgetParent != null)
			return new MenuItem ((Menu) widgetParent, SWT.SEPARATOR);
		throw new CreatorException (decodeEngine, null, this, parentNS, parentTag, elm, parentObj);
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine)
	{
		return obj;
	}
}
