/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.setter;

import java.lang.reflect.Field;
import java.util.StringTokenizer;

import org.eclipse.swt.SWT;

import cookxml.cookswt.exception.BadKeyException;
import cookxml.core.DecodeEngine;
import cookxml.core.doclet.DocletActionReporter;
import cookxml.core.exception.CookXmlException;
import cookxml.core.interfaces.Setter;
import cookxml.core.interfaces.TagLibrary;
import cookxml.core.setter.DefaultSetter;

/**
 * This setter is used to set accerlator key attribute.
 *
 * @author Heng Yuan
 * @version $Id: AcceleratorSetter.java 221 2007-06-06 06:44:13Z coconut $
 * @since CookSwt 1.0
 */
public class AcceleratorSetter implements Setter, DocletActionReporter
{
	public void setAttribute (String ns, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine)
	{
		if (value == null ||
			!(value instanceof String))
			return;

		int key = getKey ((String) value, decodeEngine);

		DefaultSetter.getInstance ().setAttribute (ns, tag, attrNS, attr, obj, new Integer (key), decodeEngine);
	}

	public static int getKey (String value, DecodeEngine decodeEngine) throws CookXmlException
	{
		int key = 0;
		try
		{
			StringTokenizer tokenizer = new StringTokenizer (value, "| ");
			do
			{
				String token = tokenizer.nextToken ();
				if (token.length () == 0)
					break;
				else if (token.length () == 1)
				{
					key |= token.charAt (0);
				}
				else
				{
					Field field = SWT.class.getField (token);
					key |= field.getInt (null);
				}
			}
			while (tokenizer.hasMoreTokens ());
		}
		catch (Exception ex)
		{
			decodeEngine.handleException (null, new BadKeyException (SWT.class, value));
		}
		return key;
	}

	public Object[] getActions (TagLibrary tagLibrary, String tagNS, String tag, String attrNS, String attr, Class cl)
	{
		return DefaultSetter.getInstance ().getActions (tagLibrary, tagNS, tag, attrNS, attr, int.class);
	}
}
