/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.setter;

import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Widget;

import cookxml.cookswt.converter.ColorConverter;
import cookxml.cookswt.converter.ImageConverter;
import cookxml.cookswt.util.SwtUtils;
import cookxml.core.DecodeEngine;
import cookxml.core.doclet.DocletActionReporter;
import cookxml.core.exception.SetterException;
import cookxml.core.interfaces.Setter;
import cookxml.core.interfaces.TagLibrary;
import cookxml.core.setter.DefaultSetter;

/**
 * This setter is used to set color or image attributes and install a DisposeListener at the same
 * time.
 *
 * @see cookxml.cookswt.util.ColorDisposeListener
 * @see cookxml.cookswt.util.ImageDisposeListener
 * @author Heng Yuan
 * @version $Id: ColorAndImageSetter.java 221 2007-06-06 06:44:13Z coconut $
 * @since CookSwt 1.0
 */
public class ColorAndImageSetter implements Setter, DocletActionReporter
{
	private static Setter s_instance = new ColorAndImageSetter ();

	public static Setter getInstance ()
	{
		return s_instance;
	}

	private ColorAndImageSetter ()
	{
	}

	public void setAttribute (String ns, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine)
	{
		if (value instanceof String)
		{
			Color color = ColorConverter.getColor ((String) value);
			if (color == null)
			{
				try
				{
					value = ImageConverter.getInstance ().convert ((String) value, decodeEngine);
				}
				catch (Exception ex)
				{
				}
			}
			else
				value = color;
		}
		if (value == null)
			throw new SetterException (decodeEngine, null, this, ns, tag, attrNS, attr, obj, value);

		DefaultSetter.getInstance ().setAttribute (ns, tag, attrNS, attr, obj, value, decodeEngine);

		if (obj == null ||
			!(obj instanceof Widget))
			return;
		if (value instanceof Color)
			SwtUtils.attachColorDisposeListener ((Widget) obj, (Color) value);
		else if (value instanceof Image)
			SwtUtils.attachImageDisposeListener ((Widget) obj, (Image) value);
	}

	public Object[] getActions (TagLibrary tagLibrary, String tagNS, String tag, String attrNS, String attr, Class cl)
	{
		Object[] arr1 = DefaultSetter.getInstance ().getActions (tagLibrary, tagNS, tag, attrNS, attr, Image.class);
		Object[] arr2 = DefaultSetter.getInstance ().getActions (tagLibrary, tagNS, tag, attrNS, attr, Color.class);
		Object[] arr3 = new Object[arr1.length + arr2.length];
		for (int i = 0; i < arr1.length; ++i)
			arr3[i] = arr1[i];
		int len = arr1.length;
		for (int i = 0; i < arr2.length; ++i)
			arr3[len + i] = arr2[i];
		return arr3;
	}
}
