/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.setter;

import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Widget;

import cookxml.cookswt.converter.ImageConverter;
import cookxml.cookswt.util.SwtUtils;
import cookxml.core.DecodeEngine;
import cookxml.core.doclet.DocletActionReporter;
import cookxml.core.exception.SetterException;
import cookxml.core.interfaces.Setter;
import cookxml.core.interfaces.TagLibrary;
import cookxml.core.setter.DefaultSetter;

/**
 * This setter is used to set image attribute and install a ImageDisposeListener at the same
 * time.
 *
 * @see cookxml.cookswt.util.ImageDisposeListener
 * @author Heng Yuan
 * @version $Id: ImageSetter.java 221 2007-06-06 06:44:13Z coconut $
 * @since CookSwt 1.0
 */
public class ImageSetter implements Setter, DocletActionReporter
{
	private static Setter s_instance = new ImageSetter ();

	public static Setter getInstance ()
	{
		return s_instance;
	}

	private ImageSetter ()
	{
	}

	public void setAttribute (String ns, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine)
	{
		if (value instanceof String)
			value = ImageConverter.getInstance ().convert ((String) value, decodeEngine);

		if (value == null || !(value instanceof Image))
			throw new SetterException (decodeEngine, null, this, ns, tag, attrNS, attr, obj, value);

		DefaultSetter.getInstance ().setAttribute (ns, tag, attrNS, attr, obj, value, decodeEngine);

		if (obj != null && (obj instanceof Widget))
			SwtUtils.attachImageDisposeListener ((Widget) obj, (Image) value);
	}

	public Object[] getActions (TagLibrary tagLibrary, String tagNS, String tag, String attrNS, String attr, Class cl)
	{
		return DefaultSetter.getInstance ().getActions (tagLibrary, tagNS, tag, attrNS, attr, Image.class);
	}
}
