/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.ui;

import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.*;

import cookxml.cookswt.CookSwt;
import cookxml.core.util.DocumentElement;

/**
 * This dialog is used for creating dialogs from XML.  The root of of the XML document
 * must be a shell.
 *
 * @author Heng Yuan
 * @version $Id: XmlDialog.java 217 2007-06-06 06:00:53Z coconut $
 * @since CookSwt 1.0
 */
public class XmlDialog extends Dialog
{
	/**
	 * This selection listener is provided for convenience of disposing a Dialog
	 * from a MenuItem, a Control (such as Button), or ToolItem inside the Dialog.
	 * <p/>
	 * If you used your SelectionListener for the button instead, and wish to
	 * dispose the dialog in the end, re-direct the action to this one near the end.
	 */
	public final static SelectionListener closeAction = new SelectionAdapter ()
	{
		public void widgetSelected (SelectionEvent e)
		{
			Object widget = e.getSource ();
			if (widget instanceof Control)
				((Control) widget).getShell ().dispose ();
			else if (widget instanceof MenuItem)
				((MenuItem) widget).getParent ().getShell ().dispose ();
			else if (widget instanceof ToolItem)
				((ToolItem) widget).getParent ().getShell ().dispose ();
		}
	};

	/**
	 * The XML document source.
	 */
	private DocumentElement m_xml;
	/**
	 * Object where all the variables are located.
	 */
	private Object m_varObj;

	public XmlDialog (Shell parent)
	{
		super (parent, 0);
	}

	public XmlDialog (Shell parent, int style)
	{
		super (parent, style);
	}

	public Object open ()
	{
		Shell parent = getParent ();
		CookSwt cookSwt = new CookSwt (m_varObj == null ? this : m_varObj);
		try
		{
			Shell shell = (Shell) cookSwt.xmlDecode (m_xml, null, "shell", parent);
			String title = getText ();
			if (title != null && title.length () > 0)
				shell.setText (title);
			shell.open ();
			Display display = parent.getDisplay ();
			while (!shell.isDisposed ())
			{
				if (!display.readAndDispatch ()) display.sleep ();
			}
		}
		catch (Exception ex)
		{
		}
		return getResult ();
	}

	/**
	 * Overload this function to provide a return value.
	 *
	 * @return	result from dialog.
	 */
	public Object getResult ()
	{
		return null;
	}

	/**
	 * Get the XML source.
	 *
	 * @return	the XML source.
	 */
	public DocumentElement getXml ()
	{
		return m_xml;
	}

	/**
	 * Set the XML source.
	 *
	 * @param xml the XML source.
	 */
	public void setXml (DocumentElement xml)
	{
		m_xml = xml;
	}

	/**
	 * Get the variable object.
	 *
	 * @return	the variable object.
	 */
	public Object getVarObj ()
	{
		return m_varObj;
	}

	/**
	 * Set the variable object.
	 *
	 * @param varObj the variable object.
	 */
	public void setVarObj (Object varObj)
	{
		m_varObj = varObj;
	}
}
