/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.util;

import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.graphics.Color;

/**
 * This DisposeListener attempts to dispose a color resource when the Widget using
 * it is disposed.
 *
 * @see Color
 * @see SwtUtils#attachColorDisposeListener(org.eclipse.swt.widgets.Widget,org.eclipse.swt.graphics.Color)
 * @author Heng Yuan
 * @version $Id: ColorDisposeListener.java 217 2007-06-06 06:00:53Z coconut $
 * @since CookSwt 1.0
 */
public class ColorDisposeListener implements DisposeListener
{
	private final Color m_color;

	public ColorDisposeListener (Color color)
	{
		m_color = color;
	}

	public void widgetDisposed (DisposeEvent e)
	{
		if (!m_color.isDisposed ())
		{
			assert SwtUtils.disposeDebug ("Dispose color: " + m_color);
			m_color.dispose ();
		}
	}
}
