/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookswt.util;

import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.graphics.Font;

/**
 * This DisposeListener attempts to dispose a font resource when the Widget using
 * it is disposed.
 *
 * @see Font
 * @see SwtUtils#attachFontDisposeListener(org.eclipse.swt.widgets.Widget,org.eclipse.swt.graphics.Font)
 * @author Heng Yuan
 * @version $Id: FontDisposeListener.java 217 2007-06-06 06:00:53Z coconut $
 * @since CookSwt 1.0
 */
public class FontDisposeListener implements DisposeListener
{
	private final Font m_font;

	public FontDisposeListener (Font font)
	{
		m_font = font;
	}

	public void widgetDisposed (DisposeEvent e)
	{
		if (!m_font.isDisposed ())
		{
			assert SwtUtils.disposeDebug ("Dispose font: " + m_font);
			m_font.dispose ();
		}
	}
}
