/*
 */
package examples.cookswt;

import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

import org.eclipse.swt.SWT;
import org.eclipse.swt.browser.Browser;
import org.eclipse.swt.events.*;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.*;

import cookxml.cookswt.CookSwt;
import cookxml.cookswt.ui.XmlDialog;
import cookxml.cookswt.util.SwtUtils;
import cookxml.core.IdReference;
import cookxml.core.exception.CookXmlException;
import cookxml.core.util.TextUtils;

import examples.util.XmlToHtmlConverter;

/**
 * This class serves two purposes.  One is to demonstrate the pre-built GUI xml form files.
 * Another is to preview user's own XML form files.
 *
 * @author Heng Yuan
 */
public class CookSwtDemo
{
	public String msgCopyright;
	public MessageBox exitMessageBox;
	public FileDialog openFileDialog;
	public XmlDialog aboutDialog;
	public Browser xmlPane;
	public TabFolder tabPane;
	public TabItem swtTab;
	public Composite oldWidget;
	public Label statusBar;
	public String msgExitCanceled;
	public ToolTip toolTip;

	public Map systemProperties = readSystemProperties ();

	private final CookSwt m_cookSwt;

	private static String[] s_propertyKeys =
			{
				"java.version",
				"java.vender",
				"java.vendor.url",
				"java.home",
				"java.vm.specification.version",
				"java.vm.specification.vendor",
				"java.vm.specification.name",
				"java.vm.version",
				"java.vm.vendor",
				"java.vm.name",
				"java.specification.version",
				"java.specification.vendor",
				"java.specification.name",
				"java.class.version",
				"java.class.path",
				"java.library.path",
				"java.io.tmpdir",
				"java.compiler",
				"java.ext.dirs",
				"os.name",
				"os.arch",
				"os.version",
				"file.separator",
				"path.separator",
				"line.separator",
				"user.name",
				"user.home",
				"user.dir"
			};

	private static Map readSystemProperties ()
	{
		try
		{
			return System.getProperties ();
		}
		catch (Exception ex)
		{
			// there is a security manager, so we can try to get it using getProperty instead
			Map properties = new HashMap ();
			String[] propertyKeys = s_propertyKeys;
			for (int i = 0; i < propertyKeys.length; ++i)
			{
				try
				{
					String key = propertyKeys[i];
					String value = System.getProperty (key);
					if (value == null)
						continue;
					properties.put (key, value);
				}
				catch (Exception ex2)
				{
				}
			}
			return properties;
		}
	}

	public ShellListener shellListener = new ShellAdapter ()
	{
		public void shellClosed (ShellEvent e)
		{
			if (canExit ())
				return;
			e.doit = false;
		}
	};

	public SelectionListener exitAction = new SelectionAdapter ()
	{
		public void widgetSelected (SelectionEvent e)
		{
			if (canExit ())
				Display.getCurrent ().getShells ()[0].dispose ();
		}
	};

	public SelectionListener openAction = new SelectionAdapter ()
	{
		public void widgetSelected (SelectionEvent e)
		{
			String fileName = openFileDialog.open ();
			if (fileName != null)
				doOpenXml (fileName);
		}
	};

	public SelectionListener toolTipAction = new SelectionAdapter ()
	{
		public void widgetSelected (SelectionEvent e)
		{
			toolTip.setVisible (true);
		}
	};
	public SelectionListener dialogAction = new SelectionAdapter ()
	{
		public void widgetSelected (SelectionEvent e)
		{
			String str = e.getSource ().toString ();
			int start = str.indexOf ("{");
			int end = str.indexOf ("}");
			if (start < 0 || end < 0 || start > end)
				return;
			str = str.substring (start + 1, end);
			if (str.length () == 0)
				return;
			IdReference idref = m_cookSwt.getId (str);
			if (idref == null)
				return;
			Object obj = idref.object;
			if (obj == null || !(obj instanceof Dialog))
				return;
			try
			{
				Method method = obj.getClass ().getMethod ("open", new Class[0]);
				method.invoke (obj, new Object[0]);
			}
			catch (Exception ex)
			{
			}
		}
	};

	public SelectionListener comboBoxAction = new SelectionAdapter ()
	{
		public void widgetSelected (SelectionEvent e)
		{
			String str = e.getSource ().toString ();
			int start = str.indexOf ("{");
			int end = str.indexOf ("}");
			if (start < 0 || end < 0 || start > end)
				return;
			str = str.substring (start + 1, end);
			if (str.length () == 0)
				return;
			doOpenXml ("examples/cookswt/xml/" + str);
		}
	};

	public SelectionListener buttonAction = new SelectionAdapter ()
	{
		public void widgetSelected (SelectionEvent e)
		{
			statusBar.setText (e.getSource ().toString ());
		}
	};

	public SelectionListener aboutAction = new SelectionAdapter ()
	{
		public void widgetSelected (SelectionEvent e)
		{
			aboutDialog.open ();
		}
	};

	/**
	 * For disposing the about dialog box.
	 */
	public SelectionListener disposeAboutAction = new SelectionAdapter ()
	{
		public void widgetSelected (SelectionEvent e)
		{
			XmlDialog.closeAction.widgetSelected (e);
		}
	};

	public boolean canExit ()
	{
		int choice = exitMessageBox.open ();
		if (choice == SWT.OK)
			return true;
		statusBar.setText (msgExitCanceled);
		return false;
	}

	public void doOpenXml (String input)
	{
		CookSwt cookSwt = new CookSwt (this);		// just to for hooking up buttonAction
		if (oldWidget != null)
			oldWidget.dispose ();
		oldWidget = new Composite (tabPane, SWT.BORDER);
		oldWidget.setLayout (new FillLayout ());
		try
		{
			cookSwt.xmlDecode (input, null, "composite", oldWidget);
		}
		catch (CookXmlException ex)
		{
			ex.printStackTrace ();
		}
		swtTab.setControl (oldWidget);
		String html = null;
		try
		{
			html = XmlToHtmlConverter.convert ("", TextUtils.readText (input));
		}
		catch (Exception ex)
		{
			html = "<html><body><h1>Error reading XML code.</h1></body></html>";
		}
		xmlPane.setText (html);
		statusBar.setText (input);
	}

	public CookSwtDemo (String input)
	{
		m_cookSwt = new CookSwt (this);
		if (input != null)
			doOpenXml (input);
	}

	public void show () throws CookXmlException
	{
		SwtUtils.showDisplay ((Display) m_cookSwt.xmlDecode ("examples/cookswt/xml/cookswtdemo.xml"));
	}

	public static void main (String[] args) throws CookXmlException
	{
		CookSwtDemo demo = new CookSwtDemo (args.length > 0 ? args[0] : null);
		demo.show ();
	}
}
