/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxml;

import cookxml.cookxml.setter.*;
import cookxml.core.interfaces.SpecialCreator;
import cookxml.core.taglibrary.SingleNSTagLibrary;

/**
 * This class creates a CookXml tag library for CookXml special attributes.
 * <p>
 * The special attributes are fairly powerful.  So it is not a good idea to
 * include them in all the XML parsers.
 * <p>
 * This tag library is included in the CookXml Common singleton instance.
 *
 * @since CookXml 3.0
 * @author Heng Yuan
 */
public class CookXmlLib
{
	public static String NAMESPACE = "http://cookxml.sf.net/";
	/**
	 * write the id reference
	 */
	public static String ID_ATTR = "id";
	/**
	 * write access to the variable
	 */
	public static String VAR_ATTR = "var";
	/**
	 * the tag attribute for casting the current tag into a new tag name.
	 */
	public static String TAG_ATTR = "tag";
	/**
	 * read the id reference
	 */
	public static String IDREF_ATTR = "idref";
	/**
	 * read access to the variable
	 */
	public static String VARREF_ATTR = "varref";
	/**
	 * the setter attribute
	 */
	public static String SETAS_ATTR = "setas";
	/**
	 * the direct function call attribute
	 */
	public static String FUNC_ATTR = "func";
	/**
	 * the attribute to specify whether or not to add the current object to the parent.
	 * By default a child is add to the parent object unless some contraints are in place.
	 * This is another contraint that can limit the addition of the object to the parent.
	 */
	public static String ADD_ATTR = "add";

	public static SingleNSTagLibrary createTagLibrary ()
	{
		SingleNSTagLibrary tagLibrary = new SingleNSTagLibrary ()
		{
			public SpecialCreator getSpecialCreator ()
			{
				return new CookXmlSpecialCreator ();
			}
		};
		tagLibrary.setNameSpace (NAMESPACE);
		tagLibrary.setSetter (null, ID_ATTR, new IdSetter ());
		tagLibrary.setSetter (null, VAR_ATTR, new VarSetter ());
		tagLibrary.setSetter (null, TAG_ATTR, new TagSetter ());
		tagLibrary.setSetter (null, SETAS_ATTR, new SetasSetter ());
		tagLibrary.setSetter (null, FUNC_ATTR, new FuncSetter ());
		tagLibrary.setSetter (null, ADD_ATTR, new AddSetter ());
		return tagLibrary;
	}

	/**
	 * Get the singleton instance of the CookXml tag library.  Use this function
	 * if you want to conserve the memory in setting up multiple tag libraries that
	 * uses the cookxml tag library.
	 * <p>
	 * This instance of library is not created until this functio is called.
	 *
	 * @return  the global instance of the
	 */
	public static SingleNSTagLibrary getSingletonTagLibrary ()
	{
		return CookXmlLibSingleton.getTagLibrary ();
	}
}
