/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxml;

import org.w3c.dom.Attr;
import org.w3c.dom.Element;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.CookXmlException;
import cookxml.core.exception.CreatorException;
import cookxml.core.interfaces.Creator;
import cookxml.core.interfaces.SpecialCreator;

/**
 * @author Heng Yuan
 * @since	CookXml 3.0
 */
class CookXmlSpecialCreator implements SpecialCreator
{
	private final Creator m_idrefCreator = new Creator ()
	{
		public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine) throws CreatorException
		{
			Attr attrNode = Util.getAttributeNode (elm, CookXmlLib.NAMESPACE, CookXmlLib.IDREF_ATTR);
			String tagNS = elm.getNamespaceURI ();
			String tag = null;
			if (tagNS == null)
				tag = elm.getTagName ();
			else
				tag = elm.getLocalName ();
			if (attrNode == null)
				throw new CreatorException (decodeEngine, null, this, parentNS, parentTag, elm, parentObj);
			decodeEngine.setCurrentTag (tagNS, tag);
			decodeEngine.addCurrentSkipList (attrNode);
			return decodeEngine.getCookXml ().getId (attrNode.getNodeValue ()).object;
		}

		public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine) throws CookXmlException
		{
			return obj;
		}
	};

	private final Creator m_varrefCreator = new Creator ()
	{
		public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine) throws CreatorException
		{
			Attr attrNode = Util.getAttributeNode (elm, CookXmlLib.NAMESPACE, CookXmlLib.VARREF_ATTR);
			String tagNS = elm.getNamespaceURI ();
			String tag = null;
			if (tagNS == null)
				tag = elm.getTagName ();
			else
				tag = elm.getLocalName ();
			if (attrNode == null)
				throw new CreatorException (decodeEngine, null, this, parentNS, parentTag, elm, parentObj);
			decodeEngine.setCurrentTag (tagNS, tag);
			decodeEngine.addCurrentSkipList (attrNode);
			return decodeEngine.getVariable (attrNode.getNodeValue ());
		}

		public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine) throws CookXmlException
		{
			return obj;
		}
	};

	public Creator getCreator (DecodeEngine decodeEngine, String parentNS, String parentTag, Element elm, Object parentObj)
	{
		if (Util.getAttributeNode (elm, CookXmlLib.NAMESPACE, CookXmlLib.IDREF_ATTR) != null)
			return m_idrefCreator;
		if (Util.getAttributeNode (elm, CookXmlLib.NAMESPACE, CookXmlLib.VARREF_ATTR) != null)
			return m_varrefCreator;
		String tagNS = elm.getNamespaceURI ();
		if (tagNS != null)
			return null;
		if (elm.getAttributeNode (CookXmlLib.IDREF_ATTR) != null)
			return m_idrefCreator;
		if (elm.getAttributeNode (CookXmlLib.VARREF_ATTR) != null)
			return m_varrefCreator;
		return null;
	}
}
