/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxml;

import org.w3c.dom.Attr;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;

/**
 * @author Heng Yuan
 * @since CookXml 3.0
 */
public class Util
{
	/**
	 * Retrieve the attribute node that corresponds to the namespaceURI and localName.
	 * <p>
	 * This function avoids the crimson bug in Sun SDK 1.4.2.
	 *
	 * @param	elm
	 *			the DOM element.
	 * @param	namespaceURI
	 *			the namespace of the attribute node to be matched.  This value can be null.
	 * @param	localName
	 *			the attribute name of the attribute node to be matched. 
\	 */
	public static Attr getAttributeNodeNS (Element elm, String namespaceURI, String localName)
	{
		if (localName == null)
			return null;
		NamedNodeMap attributes = elm.getAttributes ();
		if (attributes == null)
			return null;
		int size = attributes.getLength ();
		for (int i = 0; i < size; ++i)
		{
			Attr attr = (Attr)attributes.item (i);
			if (localName.equals (attr.getLocalName ()))
			{
				String ns = attr.getNamespaceURI ();
				if (ns == namespaceURI || (namespaceURI != null && namespaceURI.equals (ns)))
					return attr;
			}
		}
		return null;
	}

	/**
	 * Retrieve the attribute node that corresponds to the namespaceURI and localName.
	 * If not found, and if the namespace of the tag is null, then try to retrieve the
	 * attribute with null namespace and the localName.
	 *
	 * @param	elm
	 *			the DOM element.
	 * @param	namespaceURI
	 *			the namespace of the attribute node to be matched.  This value must not be null.
	 * @param	localName
	 *			the attribute name of the attribute node to be matched.
\	 */
	public static Attr getAttributeNode (Element elm, String namespaceURI, String localName)
	{
		if (localName == null)
			return null;
		NamedNodeMap attributes = elm.getAttributes ();
		if (attributes == null)
			return null;
		int size = attributes.getLength ();
		for (int i = 0; i < size; ++i)
		{
			Attr attr = (Attr)attributes.item (i);
			if (localName.equals (attr.getLocalName ()))
			{
				String ns = attr.getNamespaceURI ();
				if (ns == namespaceURI || namespaceURI.equals (ns))
					return attr;
			}
		}
		if (elm.getNamespaceURI () != null)
			return null;
		for (int i = 0; i < size; ++i)
		{
			Attr attr = (Attr)attributes.item (i);
			if (localName.equals (attr.getLocalName ()) && attr.getNamespaceURI () == null)
				return attr;
		}
		return null;
	}
}
