/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxml.setter;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.SetterException;
import cookxml.core.interfaces.Setter;

/**
 * This setter set the current tag name.
 *
 * @since CookXml 3.0
 * @author Heng Yuan
 */
public class TagSetter implements Setter
{
	public void setAttribute (String tagNS, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine) throws SetterException
	{
		if (value == null || !(value instanceof String))
			throw new IllegalArgumentException ("Invalid tag name: " + value);
		String str = (String)value;
		if (str.length () == 0)
			throw new IllegalArgumentException ("Invalid tag name: " + value);
		int index = str.indexOf (':');
		if (index <= 0)
			decodeEngine.setCurrentTag (str);
		else
		{
			String nsPrefix = str.substring (0, index);
			String newTag = str.substring (index + 1);
			String newNS = decodeEngine.getPrefixNameSpace (nsPrefix);
			if (newNS == null || newTag.length () == 0)
				throw new IllegalArgumentException ("Invalid tag name: " + str);
			decodeEngine.setCurrentTag (newNS, newTag);
		}
	}
}
