/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc;

import java.lang.reflect.Method;

import org.w3c.dom.Element;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Adder;
import cookxml.core.interfaces.Creator;
import cookxml.core.interfaces.Setter;

/**
 * @author Heng Yuan
 * @version $Id: Utils.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookXmlDoc 0.1
 */
class Utils
{
	private final static Class[] CREATOR_SIG = new Class[]
	{
		String.class,
		String.class,
		Element.class,
		Object.class,
		DecodeEngine.class
	};

	private final static Class[] ADDER_SIG = new Class[]
	{
		String.class,
		String.class,
		Object.class,
		Object.class,
		DecodeEngine.class
	};

	private final static Class[] SETTER_SIG = new Class[]
	{
		String.class,
		String.class,
		String.class,
		String.class,
		Object.class,
		Object.class,
		DecodeEngine.class
	};

	public static Method getCreatorMethod (Creator creator)
	{
		try
		{
			return creator.getClass ().getMethod ("create", CREATOR_SIG);
		}
		catch (Exception ex)
		{
			return null;
		}
	}

	public static Method getAdderMethod (Adder adder)
	{
		try
		{
			return adder.getClass ().getMethod ("add", ADDER_SIG);
		}
		catch (Exception ex)
		{
			return null;
		}
	}

	public static Method getSetterMethod (Setter setter)
	{
		try
		{
			return setter.getClass ().getMethod ("setAttribute", SETTER_SIG);
		}
		catch (Exception ex)
		{
			return null;
		}
	}
}
