/*
 * cookxml.cookxmldoc.htmldoclet.syntaxhighlighter.SyntaxUtilities.java - Utility functions used by syntax colorizing
 * Copyright (C) 1999 Slava Pestov
 *
 * You may use and modify this package for any purpose. Redistribution is
 * permitted, in both source and binary form, provided that this notice
 * remains intact in all source distributions of this package.
 */
package cookxml.cookxmldoc.htmldoclet.highlighter;

import javax.swing.text.Segment;

/**
 * Class with several utility functions used by jEdit's syntax colorizing
 * subsystem.
 *
 * @author Slava Pestov
 * @version $Id:SyntaxUtilities.java 179 2007-06-04 14:23:19Z coconut $
 */
public class SyntaxUtilities
{
	/**
	 * Checks if a subregion of a <code>Segment</code> is equal to a
	 * string.
	 *
	 * @param ignoreCase True if case should be ignored, false otherwise
	 * @param text	   The segment
	 * @param offset	 The offset into the segment
	 * @param match	  The string to match
	 */
	public static boolean regionMatches (boolean ignoreCase, Segment text,
										 int offset, String match)
	{
		int length = offset + match.length ();
		char[] textArray = text.array;
		if (length > text.offset + text.count)
			return false;
		for (int i = offset, j = 0; i < length; i++, j++)
		{
			char c1 = textArray[i];
			char c2 = match.charAt (j);
			if (ignoreCase)
			{
				c1 = Character.toUpperCase (c1);
				c2 = Character.toUpperCase (c2);
			}
			if (c1 != c2)
				return false;
		}
		return true;
	}

	/**
	 * Checks if a subregion of a <code>Segment</code> is equal to a
	 * character array.
	 *
	 * @param ignoreCase True if case should be ignored, false otherwise
	 * @param text	   The segment
	 * @param offset	 The offset into the segment
	 * @param match	  The character array to match
	 */
	public static boolean regionMatches (boolean ignoreCase, Segment text,
										 int offset, char[] match)
	{
		int length = offset + match.length;
		char[] textArray = text.array;
		if (length > text.offset + text.count)
			return false;
		for (int i = offset, j = 0; i < length; i++, j++)
		{
			char c1 = textArray[i];
			char c2 = match[j];
			if (ignoreCase)
			{
				c1 = Character.toUpperCase (c1);
				c2 = Character.toUpperCase (c2);
			}
			if (c1 != c2)
				return false;
		}
		return true;
	}
}
