/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc.impl;

import java.lang.reflect.Member;

import cookxml.cookxmldoc.interfaces.AttrDoc;
import cookxml.cookxmldoc.interfaces.NameSpaceDoc;
import cookxml.cookxmldoc.interfaces.TagDoc;
import cookxml.core.interfaces.Setter;

/**
 * @author Heng Yuan
 * @since CookXmlDoc 0.1
 */
public class AttrDocImpl implements AttrDoc, Comparable
{
	private final NameSpaceDoc m_ns;
	private final TagDoc m_tag;
	private final String m_attr;
	private final Setter m_setter;

	private Class m_valueClass;
	private String m_docComment = "";
	private String m_tagComment = "";
	private Member m_member;

	public AttrDocImpl (TagDocImpl tag, String attr, Setter setter)
	{
		this ((NameSpaceDocImpl)tag.getNameSpace (), tag, attr, setter, null, null);
	}

	public AttrDocImpl (NameSpaceDocImpl ns, String attr, Setter setter)
	{
		this (ns, null, attr, setter, null, null);
	}

	public AttrDocImpl (NameSpaceDocImpl ns, TagDoc tag, String attr, Setter setter, String classComment, String tagComment)
	{
		m_tag = tag;
		m_ns = ns;
		m_attr = attr;
		m_setter = setter;
		m_docComment = classComment == null ? "" : classComment;
		m_tagComment = tagComment == null ? "" : tagComment;
	}

	public TagDoc getTag ()
	{
		return m_tag;
	}

	public NameSpaceDoc getNameSpace ()
	{
		return m_ns;
	}

	public String getName ()
	{
		return m_attr;
	}

	public void setDocComment (String docComment)
	{
		if (docComment != null && ((docComment = docComment.trim ()).length () > 0))
			m_docComment = docComment;
	}

	public String getDocComment ()
	{
		return m_docComment;
	}

	public void setTagComment (String tagComment)
	{
		if (tagComment != null && ((tagComment = tagComment.trim ()).length () > 0))
			m_tagComment = tagComment;
	}

	public String getTagComment ()
	{
		return m_tagComment;
	}

	public void setValueClass (Class valueClass)
	{
		m_valueClass = valueClass;
	}

	public Class getValueClass ()
	{
		return m_valueClass;
	}

	public Setter getSetter ()
	{
		return m_setter;
	}

	public void setMember (Member member)
	{
		m_member = member;
	}

	public Member getMember ()
	{
		return m_member;
	}

	public int compareTo (Object o)
	{
		if (this == o)
			return 0;
		if (!(o instanceof AttrDoc))
			return -1;
		AttrDoc other = (AttrDoc)o;
		int diff = getName ().compareTo (other.getName ());
		if (diff != 0)
			return diff;
		Class vc = getValueClass ();
		Class ovc = other.getValueClass ();
		diff = vc == null ? 0 : 1;
		diff -= ovc == null ? 0 : 1;
		if (diff != 0)
			return diff;
		return hashCode () - other.hashCode ();
	}
}
