/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc.impl;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.Map;

import cookxml.cookxmldoc.interfaces.*;

/**
 * @author Heng Yuan
 * @since CookXmlDoc 0.1
 */
public class NameSpaceDocImpl implements NameSpaceDoc
{
	private final TagLibraryDoc m_tagLibraryDoc;
	private final String m_ns;
	private final Collection m_converters = new LinkedList();
	private final Collection m_tags = new LinkedList ();
	private final Collection m_attrs = new LinkedList ();

	private final Map m_tagMap = new HashMap ();
	private final Map m_converterMap = new HashMap ();

	public NameSpaceDocImpl (TagLibraryDoc tagLibraryDoc, String ns)
	{
		m_tagLibraryDoc = tagLibraryDoc;
		m_ns = ns;
	}

	public TagLibraryDoc getTagLibraryDoc ()
	{
		return m_tagLibraryDoc;
	}

	public String getName ()
	{
		return m_ns;
	}

	public void addConverter (ConverterDocImpl converter)
	{
		m_converters.add (converter);
		m_converterMap.put (converter.getTargetClass ().getName (), converter);
	}

	public ConverterDoc getConverter (String className)
	{
		return (ConverterDoc)m_converterMap.get (className);
	}

	public ConverterDoc[] getConverters ()
	{
		return (ConverterDocImpl[])m_converters.toArray (new ConverterDocImpl[m_converters.size ()]);
	}

	public void addTag (TagDocImpl tag)
	{
		m_tagMap.put (tag.getName (), tag);
		m_tags.add (tag);
	}

	public TagDoc getTag (String tag)
	{
		return (TagDoc)m_tagMap.get (tag);
	}

	public TagDoc[] getTags ()
	{
		return (TagDocImpl[])m_tags.toArray (new TagDocImpl[m_tags.size ()]);
	}

	public void addAttribute (AttrDoc attr)
	{
		m_attrs.add (attr);
	}

	public AttrDoc[] getAttributes ()
	{
		return (AttrDocImpl[])m_attrs.toArray (new AttrDocImpl[m_attrs.size ()]);
	}

	public String toString ()
	{
		if (m_ns == null)
			return "";
		return m_ns;
	}
}
