/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc.impl;

import java.util.*;

import cookxml.cookxmldoc.interfaces.AdderDoc;
import cookxml.cookxmldoc.interfaces.AttrDoc;
import cookxml.cookxmldoc.interfaces.NameSpaceDoc;
import cookxml.cookxmldoc.interfaces.TagDoc;
import cookxml.core.interfaces.Creator;

/**
 * @author Heng Yuan
 * @version $Id: TagDocImpl.java 247 2007-06-07 06:57:03Z coconut $
 * @since CookXmlDoc 0.1
 */
public class TagDocImpl implements TagDoc
{
	private final NameSpaceDoc m_ns;
	private final Creator m_creator;
	private final String m_tag;
	private final Collection m_attrs = new LinkedList ();
	private final Collection m_adders = new LinkedList ();
	private final Set m_children = new HashSet ();
	private final Set m_parents = new HashSet ();

	private String m_className;
	private String m_helperClassName;
	private String m_docComment = "";
	private String m_tagComment = "";
	private String[] m_examples = new String[0];

	public TagDocImpl (NameSpaceDocImpl ns, Creator creator, String tag)
	{
		m_ns = ns;
		m_creator = creator;
		m_tag = tag;
	}

	public NameSpaceDoc getNameSpace ()
	{
		return m_ns;
	}

	public boolean isInternal ()
	{
		return m_creator == null;
	}

	public String getName ()
	{
		return m_tag;
	}

	public void setDocComment (String docComment)
	{
		if (docComment != null && ((docComment = docComment.trim ()).length () > 0))
			m_docComment = docComment;
	}

	public String getDocComment ()
	{
		return m_docComment;
	}

	public void setTagComment (String tagComment)
	{
		if (tagComment != null && ((tagComment = tagComment.trim ()).length () > 0))
			m_tagComment = tagComment;
	}

	public String getTagComment ()
	{
		return m_tagComment;
	}

	public void addParent (TagDocImpl parent)
	{
		parent.m_children.add (this);
		m_parents.add (parent);
	}

	private void getParents (HashSet set)
	{
		for (Iterator iter = m_parents.iterator (); iter.hasNext ();)
		{
			TagDocImpl parent = (TagDocImpl)iter.next ();
			if (set.contains (parent))
				continue;
			set.add (parent);
			parent.getParents (set);
		}
	}

	public TagDoc[] getAncestors ()
	{
		HashSet set = new HashSet ();
		getParents (set);

		return (TagDoc[])set.toArray (new TagDoc[set.size ()]);
	}

	public TagDoc[] getChildren ()
	{
		return (TagDoc[])m_children.toArray (new TagDoc[m_children.size ()]);
	}

	public Creator getCreator ()
	{
		return m_creator;
	}

	public void addAdder (AdderDocImpl adderDoc)
	{
		m_adders.add (adderDoc);
	}

	public AdderDoc[] getAdders ()
	{
		return (AdderDoc[])m_adders.toArray (new AdderDocImpl[m_adders.size ()]);
	}

	public void addAttribute (AttrDocImpl attrDoc)
	{
		m_attrs.add (attrDoc);
	}

	public AttrDoc[] getAttributes ()
	{
		return (AttrDoc[])m_attrs.toArray (new AttrDocImpl[m_attrs.size ()]);
	}

	public void setClassName (String className)
	{
		m_className = className;
	}

	public String getClassName ()
	{
		return m_className;
	}

	public void setHelperClassName (String helperClassName)
	{
		m_helperClassName = helperClassName;
	}

	public String getHelperClassName ()
	{
		return m_helperClassName;
	}

	public String[] getExamples ()
	{
		return m_examples;
	}

	public void setExamples (String[] examples)
	{
		if (examples != null && examples.length > 0)
			m_examples = examples;
	}
}
