/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc.impl;

import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedList;

import cookxml.cookxmldoc.interfaces.NameSpaceDoc;
import cookxml.cookxmldoc.interfaces.TagLibraryDoc;
import cookxml.core.doclet.DocletTagLibrary;

/**
 * @author Heng Yuan
 * @since CookXmlDoc 0.1
 */
public class TagLibraryDocImpl implements TagLibraryDoc
{
	private final DocletTagLibrary m_tagLibrary;
	private final Collection m_docs = new LinkedList ();

	public TagLibraryDocImpl (DocletTagLibrary tagLibrary)
	{
		m_tagLibrary = tagLibrary;
	}

	public DocletTagLibrary getTagLibrary ()
	{
		return m_tagLibrary;
	}

	public void addNameSpace (NameSpaceDocImpl doc)
	{
		m_docs.add (doc);
	}

	public NameSpaceDoc getNameSpace (String ns)
	{
		for (Iterator iter = m_docs.iterator (); iter.hasNext ();)
		{
			NameSpaceDoc doc = (NameSpaceDoc)iter.next ();
			String name = doc.getName ();
			if (ns == name ||
				(name != null && name.equals (ns)))
				return doc;
		}
		return null;
	}

	public NameSpaceDoc[] getNameSpaces ()
	{
		return (NameSpaceDocImpl[])m_docs.toArray (new NameSpaceDocImpl[m_docs.size ()]);
	}
}
