/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc.interfaces;

import java.lang.reflect.Member;

import cookxml.core.interfaces.Adder;

/**
 * Class implementing this interface is used to hold the information of adders
 * in a tag.
 *
 * @author Heng Yuan
 * @since CookXmlDoc 0.1
 */
public interface AdderDoc
{
	/**
	 * Get the containing TagDoc for this AdderDoc.
	 *
	 * @return	the containing TagDoc.
	 */
	public TagDoc getTag ();

	/**
	 * Get the Javadoc comment.
	 *
	 * @return	the Javadoc comment.
	 */
	public String getDocComment ();

	/**
	 * Get the tag comment.
	 *
	 * @return	the tag comment.
	 */
	public String getTagComment ();

	/**
	 * Get the adder that is used to add the child.
	 *
	 * @return	the adder that does the adding.
	 */
	public Adder getAdder ();

	/**
	 * Get the class type for the child.
	 *
	 * @return	the class for the attribute value.
	 */
	public Class getChildClass ();

	/**
	 * Get the Member object that actually performs the
	 * setting action for this adder.
	 *
	 * @return	the associated Member object.
	 */
	public Member getMember ();
}
