/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc.interfaces;

import java.lang.reflect.Member;

import cookxml.core.interfaces.Setter;

/**
 * Class implementing this interface is used to hold the information regarding
 * an attribute in XML.
 * <p>
 * Some attributes are global, and thus does not have a tag assocaited with it.
 *
 * @author Heng Yuan
 * @since CookXmlDoc 0.1
 */
public interface AttrDoc
{
	/**
	 * Get the containing TagDoc for this AttrDoc.
	 *
	 * @return	the containing TagDoc.
	 */
	public TagDoc getTag ();

	/**
	 * Get the containing NameSpaceDoc for this AttrDoc.
	 *
	 * @return	the containing NameSpaceDoc.
	 */
	public NameSpaceDoc getNameSpace ();

	/**
	 * Get the name of the attribute.
	 *
	 * @return	the attribute name.
	 */
	public String getName ();

	/**
	 * Get the Javadoc comment.
	 *
	 * @return	the Javadoc comment.
	 */
	public String getDocComment ();

	/**
	 * Get the tag comment.
	 *
	 * @return	the tag comment.
	 */
	public String getTagComment ();

	/**
	 * Get the class type for the attribute value.  May be null for
	 * certain attributes.
	 *
	 * @return	the class for the attribute value.
	 */
	public Class getValueClass ();

	/**
	 * Get the setter that is used to this this attribute.
	 *
	 * @return	the setter to set this attribute.
	 */
	public Setter getSetter ();

	/**
	 * Get the Member object that actually performs the
	 * setting action for this attribute.
	 *
	 * @return	the associated Member object.
	 */
	public Member getMember ();
}
