/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc.interfaces;

/**
 * Doclet is loaded by CookXmlDoc to generate outputs from the processed
 * structure of TagLibraryDoc.
 * <p>
 * The Doclet should have a default contructor so that CookXmlDoc can
 * initiate a new instance of the Doclet.
 *
 * @author Heng Yuan
 * @since CookXmlDoc 0.1
 */
public interface Doclet
{
	/**
	 * This function is used to return the command line option parsers.
	 *
	 * @return	the command line option parsers.  It cannot be null.
	 */
	public OptionParser[] getOptionParsers ();

	/**
	 * This function does the actual processing of the TagLibraryDoc,
	 * which is a processed representation of the TagLibrary.
	 *
	 * @param	tagLibraryDoc
	 *			the processed presentation of the TagLibrary.
	 * @throws	Exception
	 *			in case of error.
	 */
	public void execute (TagLibraryDoc tagLibraryDoc) throws Exception;
}
