/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc.interfaces;

/**
 * Class implementing this interface is used to hold information about a single namespace.
 *
 * @author Heng Yuan
 * @since CookXmlDoc 0.1
 */
public interface NameSpaceDoc
{
	/**
	 * Get the containing TagLibraryDoc.
	 * @return	the containing TagLibraryDoc.
	 */
	public TagLibraryDoc getTagLibraryDoc ();

	/**
	 * Get the namespace for this NameSpaceDocImpl.  Can be null.
	 *
	 * @return	the namespace.
	 */
	public String getName ();

	/**
	 * Get a converter using the class name.
	 *
	 * @param	className
	 * 			the target class
	 * @return	the converter in the namespace that can do the conversion.
	 */
	public ConverterDoc getConverter (String className);

	/**
	 * Get the converters in this namespace.
	 *
	 * @return	the converters in this namespace.
	 */
	public ConverterDoc[] getConverters ();

	/**
	 * Get the named tag.
	 *
	 * @param	tag
	 *			the tag interested in.
	 * @return	the TagDoc for the tag.
	 */
	public TagDoc getTag (String tag);

	/**
	 * Get the tags in this namespace.
	 * @return	the tags in this namespace.
	 */
	public TagDoc[] getTags ();

	/**
	 * Get the global attributes in this namespace.
	 *
	 * @return	the global attributes in this namespace.
	 */
	public AttrDoc[] getAttributes ();
}
