/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxmldoc.interfaces;

import cookxml.core.doclet.DocletTagLibrary;

/**
 * This is the root document for documenting a DocletTagLibrary.
 *
 * @author Heng Yuan
 * @since CookXmlDoc 0.1
 */
public interface TagLibraryDoc
{
	/**
	 * Get the TagLibrary which this TagLibraryDoc is associated with.
	 *
	 * @return	the TagLibrary for this TagLibraryDoc.
	 */
	public DocletTagLibrary getTagLibrary ();

	/**
	 * Get the NameSpaceDoc for namespace.
	 *
	 * @param	ns
	 *			the namespace interested in.
	 * @return	the NameSpaceDocImpl corresponding to the namespace.
	 */
	public NameSpaceDoc getNameSpace (String ns);

	/**
	 * Get the namespaces this TagLibraryDoc contain.
	 *
	 * @return	the NameSpaceDocImpl's associated with this TagLibraryDoc.
	 */
	public NameSpaceDoc[] getNameSpaces ();
}
