/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxslt;

import java.io.File;
import java.net.URL;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import cookxml.cookxslt.helper.GeneralTagHelper;
import cookxml.cookxslt.helper.StyleSheet;
import cookxml.cookxslt.helper.Template;
import cookxml.cookxslt.pattern.PatternFactory;
import cookxml.core.CookXml;
import cookxml.core.interfaces.VarLookup;

/**
 * @author Heng Yuan
 */
public class CookXSLT
{
	private static URL s_xsltURL;
	private static Document s_inputXML;

	public static URL getXSLTURL ()
	{
		return s_xsltURL;
	}

	public static Document getInputXML ()
	{
		return s_inputXML;
	}

	public static void main (String[] args) throws Exception
	{
		if (args.length != 2)
		{
			System.out.println ("Usage: cookxslt <xml file> <xslt file>");
			return;
		}

		File inputFile = new File (args[0]);
		File xsltFile = new File (args[1]);
		s_xsltURL = xsltFile.toURL ();

		//assert Debug.debug ("-- reading input XML --");

		DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance ();
		factory.setNamespaceAware (true);
		DocumentBuilder builder = factory.newDocumentBuilder ();
		Document inputXML = builder.parse (inputFile);
		s_inputXML = inputXML;

		//assert Debug.debug ("-- reading XSLT script --");

		CookXml cookXml = new CookXml (factory.newDocumentBuilder (), CookXSLTLib.createTagLibrary (), (VarLookup)null);
		Object obj = cookXml.xmlDecode (xsltFile);

		StyleSheet ss;

		if (obj instanceof StyleSheet)
			ss = (StyleSheet)obj;
		else
		{
			ss = StyleSheet.getInstance ();
			GeneralTagHelper helper = (GeneralTagHelper)obj;
			// do some nasty manipulation to insert a new document root
			Document doc = (Document)helper.getElement ().getParentNode ();
			Element templateElm = doc.createElement ("template");
			templateElm.appendChild (helper.getElement ());
			Template template = new Template (templateElm);
			template.match = PatternFactory.createPattern ("/");
			template.add (helper);
			ss.add (template);
		}

		//assert Debug.debug ("-- applying XSLT script --");

		final Node docNode = inputXML.getDocumentElement ();

		NodeList nodeList = new NodeList (){

			public Node item (int index)
			{
				return docNode;
			}

			public int getLength ()
			{
				return 1;
			}
		};

		ss.applyTemplates (nodeList);
	}
}
