/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxslt;

import javax.xml.xpath.XPathExpression;

import cookxml.cookxslt.converter.PatternConverter;
import cookxml.cookxslt.converter.XPathExpressionConverter;
import cookxml.cookxslt.creator.ExecutorCreator;
import cookxml.cookxslt.creator.StyleSheetCreator;
import cookxml.cookxslt.helper.*;
import cookxml.cookxslt.pattern.Pattern;
import cookxml.cookxslt.setter.VersionSetter;
import cookxml.cookxslt.setter.XSLTAttributeSetter;
import cookxml.core.adder.DefaultAdder;
import cookxml.core.creator.DefaultCreator;
import cookxml.core.interfaces.SpecialCreator;
import cookxml.core.setter.DoNothingSetter;
import cookxml.core.taglibrary.SingleNSTagLibrary;

/**
 * @author Heng Yuan
 */
public class CookXSLTLib
{
	public final static String NAMESPACE = "http://www.w3.org/1999/XSL/Transform";

	public static void setupTags (SingleNSTagLibrary tagLibrary)
	{
		tagLibrary.setNameSpace (NAMESPACE);
		// sets the default adder and setters so that we don't have to deal with them
		tagLibrary.setSetter (null, null, XSLTAttributeSetter.getInstance ());
		tagLibrary.setAdder (null, DefaultAdder.getInstance ());

		tagLibrary.setSetter (null, "version", new VersionSetter ());

		tagLibrary.setConverter (XPathExpression.class, new XPathExpressionConverter ());
		tagLibrary.setConverter (Pattern.class, new PatternConverter ());

		tagLibrary.setCreator ("stylesheet", new StyleSheetCreator ());
		tagLibrary.setCreator ("template", ExecutorCreator.getCreator (Template.class));

		tagLibrary.setCreator ("text", ExecutorCreator.getCreator (Text.class));
		tagLibrary.setCreator ("if", ExecutorCreator.getCreator (If.class));
		tagLibrary.setCreator ("for-each", ExecutorCreator.getCreator (ForEach.class));

		tagLibrary.setCreator ("apply-templates", DefaultCreator.getCreator (ApplyTemplates.class));
		tagLibrary.setCreator ("value-of", DefaultCreator.getCreator (ValueOf.class));
	}

	public static XTagLibrary createTagLibrary ()
	{
		// setting up the xslt specific tag library
		SingleNSTagLibrary xsltTagLibrary = new SingleNSTagLibrary ();
		setupTags (xsltTagLibrary);
		// setting up the tag library that reads and parses the non-xslt tags
		SingleNSTagLibrary generalTagLibrary = new SingleNSTagLibrary ()
		{
			public SpecialCreator getSpecialCreator ()
			{
				return new XSpecialCreator ();
			}
		};
		generalTagLibrary.setAdder (null, DefaultAdder.getInstance ());
		generalTagLibrary.setSetter (null, null, DoNothingSetter.getInstance ());
		// now put the two tag libraries inside the XTagLibrary
		XTagLibrary tagLibrary = new XTagLibrary ();
		tagLibrary.addTagLibrary (NAMESPACE, xsltTagLibrary);
		tagLibrary.addTagLibrary (null, generalTagLibrary);
		return tagLibrary;
	}
}
