/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxslt.creator;

import java.lang.reflect.Constructor;

import org.w3c.dom.Element;

import cookxml.core.CookXml;
import cookxml.core.DecodeEngine;
import cookxml.core.exception.CookXmlException;
import cookxml.core.exception.CreatorException;
import cookxml.core.exception.NoDefaultConstructorException;
import cookxml.core.interfaces.Creator;

/**
 * This creator is for any classes that have a default constructor.
 * @since CookXml 1.0
 * @author Heng Yuan
 */
public class ExecutorCreator implements Creator
{
	private final static Class[] CLASS_PARAM = new Class[]{ Element.class };

	public static Creator getCreator (Class targetClass) throws CookXmlException
	{
		try
		{
			Constructor ctor = targetClass.getConstructor (CLASS_PARAM);
			return new ExecutorCreator (ctor);
		}
		catch (Exception ex)
		{
			CookXml.getDefaultExceptionHandler ().handleException (null, new NoDefaultConstructorException (targetClass));
			return null;
		}
	}

	private final Constructor m_ctor;

	private ExecutorCreator (Constructor ctor)
	{
		m_ctor = ctor;
	}

	public Object create (String parentNS, String parentTag, Element elm, Object parentObj, DecodeEngine decodeEngine) throws CreatorException
	{
		try
		{
			return m_ctor.newInstance (new Object[]{ elm });
		}
		catch (Exception ex)
		{
			throw new CreatorException (decodeEngine, ex, this, parentNS, parentTag, elm, parentObj);
		}
	}

	public Object editFinished (String parentNS, String parentTag, Element elm, Object parentObj, Object obj, DecodeEngine decodeEngine) throws CookXmlException
	{
		return obj;
	}
}
