/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxslt.helper;

import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.Stack;

import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/**
 * @author Heng Yuan
 */
public class StyleSheet
{
	private static StyleSheet s_instance = new StyleSheet ();

	public static StyleSheet getInstance ()
	{
		return s_instance;
	}

	public String id;
	public String version;

	private Output m_output;

	private LinkedList m_templates = new LinkedList ();
	private Stack m_nodeStack = new Stack ();

	private StyleSheet ()
	{
	}

	/**
	 * Add the template to the available template list.
	 *
	 * @param	template
	 *			the template to be added.
	 */
	public void add (Template template)
	{
		m_templates.add (template);
	}

	public void add (Output output)
	{
		m_output = output;
	}

	/**
	 * Get the template associated with the given name.
	 *
	 * @param	name
	 *			name of the template.
	 * @return	the template matching the name.
	 */
	public Template getTemplate (String name)
	{
		for (Iterator iter = m_templates.iterator (); iter.hasNext ();)
		{
			Template template = (Template)iter.next ();
			if (name.equals (template.name))
				return template;
		}
		return null;
	}

	public Collection getTemplates ()
	{
		return m_templates;
	}

	public Node getCurrentNode ()
	{
		return (Node)m_nodeStack.peek ();
	}

	public void applyTemplates (NodeList nodeList)
	{
		int size = nodeList.getLength ();
		for (int i = 0; i < size; ++i)
		{
			Node node = nodeList.item (i);
			for (Iterator iter = m_templates.iterator (); iter.hasNext ();)
				((Template)iter.next ()).apply (this, node);
		}
	}

	public void applyTemplate (NodeList nodeList, String name)
	{
		Template template = getTemplate (name);
		if (template == null)
			return;
		int size = nodeList.getLength ();
		for (int i = 0; i < size; ++i)
			template.apply (this, nodeList.item (i));
	}

	public void output (String str)
	{
		System.out.print (str);
	}

	public void execute (Node node, LinkedList list, Element elm) throws Exception
	{
		// we do parallel travelling of m_elm and m_list
		// all element tags has a corresponding XSLTHelper object in m_list
		Iterator helperIter = list.iterator ();
		for (Node child = elm.getFirstChild (); child != null; child = child.getNextSibling ())
		{
			if (child instanceof Element)
			{
				XSLTHelper helper = (XSLTHelper)helperIter.next ();
				helper.process (this, node);
			}
			else
			{
				output (child.getNodeValue ());
			}
		}
	}
}
