/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxslt.helper;

import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpression;

import org.w3c.dom.CharacterData;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * @author Heng Yuan
 */
public class ValueOf implements XSLTHelper
{
	public XPathExpression select;

	// by default, all output are escaped.
	public boolean disable_output_escaping = false;

	public void process (StyleSheet ss, Node node) throws Exception
	{
		node = (Node)select.evaluate (node, XPathConstants.NODE);
		if (node == null)
			return;
		if (node instanceof Element)
			ss.output (getText ((Element)node));
		else
			ss.output (node.getNodeValue ());
	}

	public static String getText (Element elm)
	{
		StringBuffer buffer = null;
		String text = null;

		for (Node node = elm.getFirstChild (); node != null; node = node.getNextSibling ())
		{
			if (node instanceof CharacterData)
			{
				if (text == null)
					text = ((CharacterData)node).getData ();
				else if (buffer == null)
				{
					buffer = new StringBuffer (text);
					buffer.append (((CharacterData)node).getData ());
				}
				else
					buffer.append (((CharacterData)node).getData ());
			}
		}

		if (text == null)
			return null;
		if (buffer == null)
			return text;
		return buffer.toString ();
	}
}
