/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxslt.pattern;

import java.util.Collection;

import org.w3c.dom.Node;

/**
 * @author Heng Yuan
 */
class PathPattern implements Pattern
{
	private final Pattern[] m_patterns;

	public PathPattern (Collection patterns)
	{
		m_patterns = new Pattern[patterns.size ()];
		patterns.toArray (m_patterns);
	}

	public Node match (Node node)
	{
		Pattern[] patterns = m_patterns;
		for (int i = patterns.length - 1; i >= 0; --i)
		{
			node = patterns[i].match (node);
			if (node == null)
				return null;
		}
		return node;
	}

	public String toString ()
	{
		StringBuffer buffer = new StringBuffer ();
		for (int i = 0; i < m_patterns.length; ++i)
			buffer.append (m_patterns[i]);
		return buffer.toString ();
	}
}
