/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.cookxslt.setter;

import cookxml.core.DecodeEngine;
import cookxml.core.FunctionHandler;
import cookxml.core.VariableHandler;
import cookxml.core.exception.NoHandlerException;
import cookxml.core.exception.SetterException;
import cookxml.core.interfaces.Handler;
import cookxml.core.interfaces.Setter;

/**
 * This setter attempts to call Java setter functions with the converted attribute values.
 *
 * @since CookXml 1.0
 * @author Heng Yuan
 */
public class XSLTAttributeSetter implements Setter
{
	public static String PREFIX = "set";

	private final static Setter s_instance = new XSLTAttributeSetter ();

	public static Setter getInstance ()
	{
		return s_instance;
	}

	private XSLTAttributeSetter ()
	{
	}

	public void setAttribute (String ns, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine) throws SetterException
	{
		try
		{
			Class valueClass = null;
			if (value != null && !(value instanceof String))
				valueClass = value.getClass ();

			Handler handler = decodeEngine.getHandler (ns, tag, ' ', attr, valueClass);

			// get the handler first.
			// if the handler is not in cache, then we need to find it and then put
			// it into the cache.
			if (handler == null)
			{
				String funcName = PREFIX + attr;

				handler = FunctionHandler.getHandler (obj, funcName, valueClass);
				if (handler == null)
				{
					// convert '-' to '_' as part of attribute names
					attr = attr.replace ('-', '_');
					handler = VariableHandler.getHandler (obj, attr, valueClass);
				}

				if (handler != null)
					decodeEngine.setHandler (ns, tag, ' ', attr, valueClass, handler);
			}
			//System.out.println ("obj = " + obj.getClass () + ", m_value = " + m_value);
			if (handler != null)
			{
				handler.invoke (ns, obj, value, decodeEngine);
				return;
			}
		}
		catch (Exception ex)
		{
			throw new SetterException (decodeEngine, ex, this, ns, tag, attrNS, attr, obj, value);
		}
		throw new SetterException (decodeEngine, new NoHandlerException (decodeEngine, ns, tag, attr, obj, value), this, ns, tag, attrNS, attr, obj, value);
	}
}
