/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core;

import cookxml.core.exception.AccessException;
import cookxml.core.exception.VarLookupException;
import cookxml.core.interfaces.VarLookup;
import cookxml.core.util.ClassUtils;

/**
 * Default behavior of handling a variable field.  It basically looks up the field from the class
 * using the name provided.
 *
 * @author Heng Yuan
 * @version $Id: DefaultVarLookup.java 244 2007-06-07 04:29:13Z coconut $
 * @since CookXml 2.0
 */
public class DefaultVarLookup implements VarLookup
{
	public final Object varObject;

	public DefaultVarLookup (Object varObject)
	{
		this.varObject = varObject;
	}

	public Object getVariable (String name, DecodeEngine decodeEngine) throws VarLookupException
	{
		if (varObject == null || name == null || name.length () == 0)
			return null;
		try
		{
			return ClassUtils.getField (varObject, name, decodeEngine.getCookXml ().isAccessible ());
		}
		catch (SecurityException ex)
		{
			try
			{
				decodeEngine.handleException (null, new AccessException (decodeEngine, ex, name));
				return null;
			}
			catch (Exception ex2)
			{
				throw new VarLookupException (decodeEngine, ex, this, name, null, false);
			}
		}
		catch (Exception ex)
		{
			throw new VarLookupException (decodeEngine, ex, this, name, null, true);
		}
	}

	public void setVariable (String name, Object value, DecodeEngine decodeEngine) throws VarLookupException
	{
		if (varObject == null || name == null || name.length () == 0)
			return;
		try
		{
			ClassUtils.setField (varObject, name, value, decodeEngine.getCookXml ().isAccessible ());
		}
		catch (SecurityException ex)
		{
			try
			{
				decodeEngine.handleException (null, new AccessException (decodeEngine, ex, name));
			}
			catch (Exception ex2)
			{
				throw new VarLookupException (decodeEngine, ex, this, name, value, false);
			}
		}
		catch (Exception ex)
		{
			throw new VarLookupException (decodeEngine, ex, this, name, value, false);
		}
	}
}
