/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core;

import org.w3c.dom.Element;

import cookxml.core.interfaces.Creator;
import cookxml.core.interfaces.SpecialCreator;

/**
 * This SpecialCreator pools several SpecialCreators into one.  The SpecialCreator in the front of
 * the list has the precedence.
 *
 * @author Heng Yuan
 * @version $Id: MultiSpecialCreator.java 244 2007-06-07 04:29:13Z coconut $
 * @since CookXml 3.0
 */
public class MultiSpecialCreator implements SpecialCreator
{
	private final SpecialCreator[] m_specialCreators;

	public MultiSpecialCreator (SpecialCreator[] specialCreators)
	{
		m_specialCreators = specialCreators;
	}

	public Creator getCreator (DecodeEngine decodeEngine, String parentNS, String parentTag, Element elm, Object parentObj)
	{
		SpecialCreator[] specialCreators = m_specialCreators;
		for (int i = 0; i < specialCreators.length; ++i)
		{
			Creator creator = specialCreators[i].getCreator (decodeEngine, parentNS, parentTag, elm, parentObj);
			if (creator != null)
				return creator;
		}
		return null;
	}
}
