/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core;

import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;

/**
 * This class maintains the xmlns scope setting.
 *
 * @author Heng Yuan
 * @version $Id: NameSpaceScope.java 244 2007-06-07 04:29:13Z coconut $
 * @since CookXml 3.0.1
 */
class NameSpaceScope
{
	private LinkedList m_scopeStack;

	public void newScope ()
	{
		if (m_scopeStack == null)
			m_scopeStack = new LinkedList ();
		m_scopeStack.addFirst (new HashMap ());
	}

	public void addScope (String prefix, String ns)
	{
		((HashMap)m_scopeStack.getFirst ()).put (prefix, ns);
	}

	public void exitScope ()
	{
		m_scopeStack.removeFirst ();
	}

	public String getPrefixNameSpace (String prefix)
	{
		for (Iterator iter = m_scopeStack.iterator (); iter.hasNext ();)
		{
			HashMap scope = (HashMap)iter.next ();
			Object ns = scope.get (prefix);
			if (ns != null)
				return (String)ns;
		}
		return null;
	}
}
