/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.adder;

import cookxml.core.DecodeEngine;
import cookxml.core.doclet.DocletActionReporter;
import cookxml.core.exception.AdderException;
import cookxml.core.interfaces.Adder;
import cookxml.core.interfaces.TagLibrary;

/**
 * This Adder redirect the call to set attribute instead, if the parameters
 * match.
 *
 * @author Heng Yuan
 * @version $Id: CallSetterAdder.java 223 2007-06-06 06:51:30Z coconut $
 * @since CookXml 1.0
 */
public class CallSetterAdder implements Adder, DocletActionReporter
{
	private final String m_attr;
	private final Class m_childClass;
	private final Class m_parentClass;

	public CallSetterAdder (String attr, Class parentClass, Class childClass)
	{
		m_attr = attr;
		m_childClass = childClass;
		m_parentClass = parentClass;
	}

	public boolean add (String parentNS, String parentTag, Object parent, Object child, DecodeEngine decodeEngine) throws AdderException
	{
		if (parent == null ||
			!(m_childClass != null && m_childClass.isInstance (child)) ||
			(m_parentClass != null && !m_parentClass.isInstance (parent)))
			return false;

		try
		{
			decodeEngine.callSetter (parentNS, parentTag, parentNS, m_attr, parent, child);
			return true;
		}
		catch (Exception ex)
		{
			throw new AdderException (decodeEngine, ex, this, parentNS, parentTag, parent, child);
		}
	}

	public Object[] getActions (TagLibrary tagLibrary, String tagNS, String tag, String attrNS, String attr, Class cl)
	{
		return new Object[]{ tagLibrary.getSetter (tagNS, tag, tagNS, m_attr) };
	}
}
