/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.adder;

import java.util.Iterator;
import java.util.LinkedList;

import cookxml.core.DecodeEngine;
import cookxml.core.doclet.DocletActionReporter;
import cookxml.core.interfaces.Adder;
import cookxml.core.interfaces.TagLibrary;

/**
 * This adder is used internally by InheritableTagLibrary to combine several
 * individual adders into one.
 *
 * @author Heng Yuan
 * @version $Id: CompoundAdder.java 255 2007-06-10 07:08:13Z coconut $
 * @see cookxml.core.taglibrary.InheritableTagLibrary
 * @since CookXml 1.0
 */
public class CompoundAdder implements Adder, DocletActionReporter
{
	private final LinkedList m_adderList = new LinkedList ();

	public CompoundAdder ()
	{
	}

	public boolean add (String ns, String parentTag, Object parent, Object child, DecodeEngine decodeEngine) throws Exception
	{
		for (Iterator iter = m_adderList.iterator (); iter.hasNext ();)
		{
			Adder adder = (Adder)iter.next ();
			if (adder.add (ns, parentTag, parent, child, decodeEngine))
				return true;
		}
		return false;
	}

	public void add (Adder adder)
	{
		// adder added latter has precedence
		m_adderList.addFirst (adder);
	}

	public String toString ()
	{
		return "CompoundAdder [ " + m_adderList + " ]";
	}

	public Object[] getActions (TagLibrary tagLibrary, String tagNS, String tag, String attrNS, String attr, Class cl)
	{
		// simply return all the internal adders
		return m_adderList.toArray ();
	}

	public static Adder getAdder (Adder oldAdder, Adder newAdder)
	{
		if (oldAdder == null)
			return newAdder;
		if (newAdder == null)
			return oldAdder;

		if (oldAdder instanceof CompoundAdder)
		{
			((CompoundAdder)oldAdder).add (newAdder);
			return oldAdder;
		}
		CompoundAdder tmpAdder = new CompoundAdder ();
		tmpAdder.add (oldAdder);
		tmpAdder.add (newAdder);
		return tmpAdder;
	}
}
