/*
 * (c) Copyright 2007 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.converter;

import java.lang.reflect.Constructor;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.ConverterException;
import cookxml.core.exception.NoConstructorException;
import cookxml.core.interfaces.Converter;

/**
 * This converter is used to reduce the need to create custom converter classes.
 *
 * @author Heng Yuan
 * @version $Id: CallCtorConverter.java 215 2007-06-06 03:59:41Z coconut $
 * @since CookXml 3.1
 */
public class CallCtorConverter implements Converter
{
	private final static Class[] CLASS_PARAM = { String.class };

	public static Converter getConverter (Class targetClass) throws NoConstructorException
	{
		Constructor ctor = null;
		try
		{
			ctor = targetClass.getConstructor (CLASS_PARAM);
			if (ctor != null)
				return new CallCtorConverter (ctor);
		}
		catch (Exception ex)
		{
		}
		throw new NoConstructorException (targetClass);
	}

	private final Constructor m_ctor;

	private CallCtorConverter (Constructor ctor)
	{
		m_ctor = ctor;
	}

	public Object convert (String value, DecodeEngine decodeEngine) throws ConverterException
	{
		try
		{
			return m_ctor.newInstance (new Object[]{ value });
		}
		catch (Exception ex)
		{
			throw new ConverterException (decodeEngine, ex, this, value);
		}
	}
}
