/*
 * (c) Copyright 2007 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.converter;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;

import cookxml.core.CookXml;
import cookxml.core.DecodeEngine;
import cookxml.core.exception.NoFactoryFunctionException;
import cookxml.core.interfaces.Converter;

/**
 * This converter is used to reduce the need to create custom converter classes.
 *
 * @author Heng Yuan
 * @version $Id: CallFunctionConverter.java 232 2007-06-06 07:29:37Z coconut $
 * @since CookXml 3.1
 */
public class CallFunctionConverter implements Converter
{
	private final static Class[] CLASS_PARAM = { String.class };

	public static Converter getConverter (Class targetClass, String funcName) throws NoFactoryFunctionException
	{
		Method factory;
		try
		{
			factory = targetClass.getMethod (funcName, CLASS_PARAM);
			int flag = factory.getModifiers ();
			if (Modifier.isPublic (flag) && Modifier.isStatic (flag))
				return new CallFunctionConverter (factory);
		}
		catch (Throwable t)
		{
		}
		CookXml.getDefaultExceptionHandler ().handleException (null, new NoFactoryFunctionException (targetClass, funcName));
		return null;
	}

	private final Method m_factory;

	private CallFunctionConverter (Method factory)
	{
		m_factory = factory;
	}

	public Object convert (String value, DecodeEngine decodeEngine) throws Exception
	{
		return m_factory.invoke (null, new Object[]{ value });
	}
}
