/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.converter;

import cookxml.core.DecodeEngine;
import cookxml.core.IdReference;
import cookxml.core.exception.ConverterException;
import cookxml.core.interfaces.Converter;
import cookxml.core.util.ClassUtils;

/**
 * This converter treats the string as if an pointer representing an object with id or variable names.
 * For id objects, the syntax is "id:name" and for variable objects, the syntax is "var:name".
 * <p>
 * Note that this converter should not be added to a tag library due to the potential ambiguities
 * it can creates.  Using idref and varref are recommanded.
 *
 * @since CookXml 1.0
 * @author Heng Yuan
 */
public class ObjectConverter implements Converter
{
	public static String IDREF_PREFIX = "id:";
	public static String VARREF_PREFIX = "var:";

	private final static Converter s_instance = new ObjectConverter ();

	public static Converter getInstance ()
	{
		return s_instance;
	}

	private ObjectConverter ()
	{
	}

	public Object convert (String value, DecodeEngine decodeEngine) throws ConverterException
	{
		try
		{
			if (ClassUtils.NULL_VAR.equals (value))
				return null;
			if (value.startsWith (IDREF_PREFIX))
			{
				IdReference idref = decodeEngine.getCookXml ().getId (value.substring (IDREF_PREFIX.length ()));
				return idref.object;
			}
			else if (value.startsWith (ObjectConverter.VARREF_PREFIX))
				return decodeEngine.getVariable (value.substring (VARREF_PREFIX.length ()));
		}
		catch (Exception ex)
		{
			throw new ConverterException (decodeEngine, ex, this, value);
		}
		throw new ConverterException (decodeEngine, null, this, value);
	}
}
