/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.doclet;

import cookxml.core.interfaces.TagLibrary;

/**
 * This function returns the related function/constructor/field/methods that
 * is called by creator/setter etc.  CookXmlDoc would then retrieve the JavaDoc
 * associated with Member object and use it in the documentation.
 *
 * @author Heng Yuan
 * @version $Id: DocletActionReporter.java 244 2007-06-07 04:29:13Z coconut $
 * @since CookXml 3.1
 */
public interface DocletActionReporter
{
	/**
	 * This function returns the related function/constructor/field/methods that
	 * is called by creator/setter etc.  CookXmlDoc would then retrieve the JavaDoc
	 * associated with Member object and use it in the documentation.
	 *
	 * @param	tagLibrary
	 *			the tag library being used.
	 * @param	tagNS
	 *			the namespace of the tag
	 * @param	tag
	 *			possible tag
	 * @param	attrNS
	 *			the namespace of the attribute
	 * @param	attr
	 *			the attribute
	 * @param	cl
	 *			the possible class
	 * @return	A non-empty array of actions performed by this object.
	 */
	public Object[] getActions (TagLibrary tagLibrary, String tagNS, String tag, String attrNS, String attr, Class cl);
}
