/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.doclet;

import cookxml.core.interfaces.Setter;

/**
 * This interface should be extended by all general setters (that is the
 * ones used by DecodeEngine as default in case of missing specific setter
 * for a tag) that wish to to report potential candidates of attributes.
 * <p>
 * This interface is used by CookXmlDoc to discover the list of candiate
 * attributes for a given tag.
 *
 * @author Heng Yuan
 * @version $Id: DocletSetter.java 244 2007-06-07 04:29:13Z coconut $
 * @since CookXml 3.1
 */
public interface DocletSetter extends Setter
{
	/**
	 * This function reports potential attributes that can be handled by this
	 * setter for a given class.  Usually it is done through reflection.
	 *
	 * @param	className
	 *			the class interested in.
	 * @return	an non-null array of possible attributes.
	 */
	public String[] getAttributes (Class className);
}
