/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.doclet;

import java.util.Map;

import cookxml.core.interfaces.TagLibrary;

/**
 * This interface is used for tag libraries that are wish to carry the capability
 * of being documented using CookXmlDoc.
 *
 * @author Heng Yuan
 * @version $Id: DocletTagLibrary.java 244 2007-06-07 04:29:13Z coconut $
 * @since CookXml 3.1
 */
public interface DocletTagLibrary extends TagLibrary
{
	/**
	 * This function reports the parent tagLibrary.
	 *
	 * @return	the parent TagLibrary.
	 */
	public TagLibrary getParent ();
	/**
	 * This function reports the namespaces this tag library holds.  It only
	 * reports *this* tag library's namespace, not parent tag library's.
	 * <p>
	 * Note that a namespace (a value inside the string array) can be null
	 * to indicate that the tag library does not handle namespaces.
	 *
	 * @return	the namespaces this TagLibrary holds.  It cannot be null
	 *			and its size should be at least 1.
	 */
	public String[] getNameSpaces ();
	/**
	 * This function reports the tags having the creators and are located
	 * inside this tag library.
	 * <p>
	 * The returned map uses XML namespace as the key, and a string array
	 * of tag names as the value as its entries.
	 *
	 * @return	a map using XML namespace string as the key, and String[]
	 *			as value for the tag names.
	 */
	public Map getTags ();
	/**
	 * This function reports the attributes associated with a particular tag.
	 * <p>
	 * The returned map uses XML namespace as the key, and a string array
	 * of attribute names as the value as its entries.
	 *
	 * @param	ns
	 *			the namespace of the tag.
	 * @param	tag
	 *			the tag name.
	 * @return	a map using XML namespace string as the key, and String[]
	 *			as value for the tag names.
	 */
	public Map getAttributes (String ns, String tag);
	/**
	 * This function reports the converters associated with a namespace.
	 *
	 * @param	ns
	 *			the namespace.
	 * @return	a non-null array of converters for the specified namespace.
	 */
	public Map getConverters (String ns);
}
