/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.exception;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Converter;

/**
 * This exception can be generated only when a converter is called to convert a string to a target object type.
 * @see cookxml.core.interfaces.Converter
 * @since CookXml 2.0
 * @author Heng Yuan
 */
public class ConverterException extends CookXmlException
{
	public final Converter converter;
	public final String value;

	public ConverterException (DecodeEngine decodeEngine, Throwable cause, Converter converter, String value)
	{
		super (null, decodeEngine, null, cause);
		this.converter = converter;
		this.value = value;
	}

    public String toString ()
	{
		return "Error in converting " + value + " using " + converter;
	}
}
