/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.exception;

import org.w3c.dom.Element;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Creator;

/**
 * This exception can be generated only when a Creator is called to create an object for a given tag.
 * @see cookxml.core.interfaces.Creator
 * @since CookXml 2.0
 * @author Heng Yuan
 */
public class CreatorException extends CookXmlException
{
	public final Creator creator;
	public final String parentNS;
	public final String parentTag;
	public final Element element;
	public final Object parentObject;

	public CreatorException (DecodeEngine decodeEngine, Throwable throwable, Creator creator, String parentNS, String parentTag, Element elm, Object parentObj)
	{
		super (null, decodeEngine, null, throwable);
		this.creator = creator;
		this.parentNS = parentNS;
		this.parentTag = parentTag;
		this.element = elm;
		this.parentObject = parentObj;
	}

    public String toString ()
	{
		return "Error in creating object for " + element;
	}
}
