/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.exception;

import org.w3c.dom.Element;

import cookxml.core.DecodeEngine;

/**
 * This exception is generated when DecodeEngine couldn't find a creator in the
 * tag library for the given tag.
 * <p>
 * In 2.0 this class is a child class of CookXmlException.  After some considerations,
 * it may be more appropriate to move it under CreatorException.
 * @see DecodeEngine
 * @since CookXml 2.0
 * @author Heng Yuan
 */
public class NoCreatorException extends CreatorException
{
	public final String tag;

	public NoCreatorException (DecodeEngine decodeEngine, String tag, String parentNS, String parentTag, Element elm, Object parentObj)
	{
		super (decodeEngine, null, null, parentNS, parentTag, elm, parentObj);
		this.tag = tag;
	}

    public String toString ()
	{
		return "Unable to find a creator for " + tag;
	}
}
