/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.exception;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.Setter;

/**
 * This exception can be generated only when a setter is called to set an attribute for an object.
 * @see cookxml.core.interfaces.Setter
 * @since CookXml 2.0
 * @author Heng Yuan
 */
public class SetterException extends CookXmlException
{
	public final Setter setter;
	public final String tagNS;
	public final String tag;
	public final String attrNS;
	public final String attribute;
	public final Object object;
	public final Object value;

	public SetterException (DecodeEngine decodeEngine, Throwable throwable, Setter setter, String tagNS, String tag, String attrNS, String attr, Object obj, Object value)
	{
		super (null, decodeEngine, null, throwable);
		this.setter = setter;
		this.tagNS = tagNS;
		this.tag = tag;
		this.attrNS = null;
		this.attribute = attr;
		this.object = obj;
		this.value = value;
	}

    public String toString ()
	{
		return "Error in setting " + tag + "[" + attribute + "] = " + value + " using " + setter;
	}
}
