/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.exception;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.VarLookup;

/**
 * @since CookXml 2.0
 * @author Heng Yuan
 */
public class VarLookupException extends CookXmlException
{
	public final VarLookup varLookup;
	public final String name;
	public final Object value;
	public final boolean isReadAccess;

	/**
	 * @param	decodeEngine
	 * 			the decodeEngine
	 * @param	name
	 * 			the variable name
	 * @param	value
	 * 			the value to be set
	 * @param	isReadAccess
	 * 			read or write?
	 */
	public VarLookupException (DecodeEngine decodeEngine, Throwable cause, VarLookup varLookup, String name, Object value, boolean isReadAccess)
	{
		super (null, decodeEngine, null, cause);
		this.varLookup = varLookup;
		this.name = name;
		this.value = value;
		this.isReadAccess = isReadAccess;
	}

    public String toString ()
	{
		if (isReadAccess)
			return "Error getting variable: " + name;
		else
			return "Error setting variable " + name + " with value " + value + " using " + varLookup;
	}
}
