/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.interfaces;

import org.w3c.dom.Element;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.CookXmlException;

/**
 * This action dictates how DecodeEngine should perform its addChild function.
 * This action is used internally by CookXml to deal with possible actions of
 * setas, func, add, etc.  Do not use this interface over Adder interface.
 *
 * @author Heng Yuan
 * @version $Id: AddAction.java 218 2007-06-06 06:10:10Z coconut $
 * @since CookXml 3.0
 */
public interface AddAction
{
	/**
	 * This function performs the actual addition of the child object to
	 * the parent object.
	 *
	 * @param	decodeEngine
	 *			the DecodeEngine instance being used.
	 * @param	ns
	 *			the parent tag namespace.
	 * @param	tag
	 *			the parent tag name.
	 * @param	elm
	 *			the element of the current
	 * @param	parentObj
	 *			the parent object
	 * @param	childObj
	 *			the child object
	 * @throws	CookXmlException
	 *			the exception thrown when error occurs.  Exceptions that are not
	 *			CookXmlException should be wrapped inside a CookXmlException.
	 */
	public void addChild (DecodeEngine decodeEngine, String ns, String tag, Element elm, Object parentObj, Object childObj) throws CookXmlException;
}
