/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.interfaces;

import cookxml.core.DecodeEngine;

/**
 * Adder is similar to setter, but without the attribute name.
 *
 * @author Heng Yuan
 * @version $Id: Adder.java 218 2007-06-06 06:10:10Z coconut $
 * @since CookXml 1.0
 */
public interface Adder
{
	/**
	 * Add the child to the parent.  The function should return true if it is the right
	 * adder for the request.  False if it is not.  Throw exceptions for errors.
	 *
	 * @param	parentNS
	 *			the parent tag namespace.
	 * @param	parentTag
	 * 			the parent tag name.
	 * @param	parent
	 * 			the parent object.
	 * @param	child
	 * 			the child object.
	 * @param	decodeEngine
	 * 			the DecodeEngine instance being used.
	 * @return	whether or not the adder can handle the request.
	 * @throws	Exception
	 * 			If the exception is not a {@link cookxml.core.exception.AdderException},
	 * 			then it is wrapped inside one by the DecodeEngine and handled by the
	 *			{@link cookxml.core.interfaces.ExceptionHandler}.
	 */
	public boolean add (String parentNS, String parentTag, Object parent, Object child, DecodeEngine decodeEngine) throws Exception;
}
