/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.interfaces;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.ConverterException;

/**
 * Converters are used to convert a string (obtained from an attribute value) to
 * the actual value needed by the setter.
 * 
 * @see ConverterException
 * @author Heng Yuan
 * @version $Id: Converter.java 218 2007-06-06 06:10:10Z coconut $
 * @since CookXml 1.0
 */
public interface Converter
{
	/**
	 * Convert a string value into an object type.
	 *
	 * @param	value
	 * 			the string value to be converted.
	 * @param	decodeEngine
	 * 			the DecodeEngine to be used.
	 * @return	the converted object.
	 * @throws	Exception
	 * 			If the exception is not a {@link cookxml.core.exception.ConverterException},
	 * 			then it should be wrapped inside one by the caller.
	 */
	public Object convert (String value, DecodeEngine decodeEngine) throws Exception;
}
