/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.interfaces;

import cookxml.core.exception.CookXmlException;

/**
 * This is the interface for handlers that deal with exceptions generated while
 * CookXml is decoding XML.
 *
 * @since CookXml 2.0
 * @version $Id: ExceptionHandler.java 218 2007-06-06 06:10:10Z coconut $
 * @author Heng Yuan
 */
public interface ExceptionHandler
{
	/**
	 * This function handles the exception.  To generate an error that halts
	 * the parsing process of the DecodeEngine, throw a CookXmlException.
	 * To tolerate the exception, just do not do anything.
	 *
	 * @param	msg
	 * 			The message that goes along with the exception.
	 * @param	ex
	 * 			The exception to be handled.
	 * @throws	CookXmlException
	 * 			The only type of exception this handler should throw.
	 */
	public void handleException (String msg, Exception ex) throws CookXmlException;
}
