/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.interfaces;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.HandlerException;

/**
 * This interface is used for setting an attribute value to an object.
 *
 * @see HandlerException
 * @version $Id: Handler.java 265 2007-06-10 18:47:06Z coconut $
 * @author Heng Yuan
 * @since CookXml 1.0
 */
public interface Handler
{
	/**
	 * this function is used to assign the value to the object either through
	 * a function setter or directly through variable assignment.
	 * 
	 * @param   ns
	 *          the namespace of the element being used.
	 * @param	obj
	 * 			the object where the function or the variable is located in.
	 * @param	value
     * 			the actual value to be set.
	 * @param	decodeEngine
	 * 			The decodeEngine that does the parsing.
	 * @throws	cookxml.core.exception.HandlerException
	 * 			in case of error.
	 */
	public void invoke (String ns, Object obj, Object value, DecodeEngine decodeEngine) throws HandlerException;
}
