/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.interfaces;

import cookxml.core.DecodeEngine;

/**
 * This interface is used by all setters that handle request to set a value to the object.
 *
 * @author Heng Yuan
 * @version $Id: Setter.java 218 2007-06-06 06:10:10Z coconut $
 * @since CookXml 1.0
 */
public interface Setter
{
	/**
	 * Set an attribute of the object.
	 * 
	 * @param   ns
	 *          the namespace of the element.
	 * @param	tag
	 * 			the tag of the element
	 * @param   attrNS
	 *          the namespace of the attribute
	 * @param	attr
	 * 			the name of the attribute
	 * @param	obj
	 * 			the object associated with the element
	 * @param	value
	 * 			the value of the object.  We didn't use the String type because it is
	 * 			entirely possible for an object of the child elements to call the setter.
	 * @param	decodeEngine
	 *          the DecodeEngine being used.
	 * @throws	Exception
	 * 			If the exception is not a {@link cookxml.core.exception.SetterException},
	 * 			then it is wrapped inside one by the DecodeEngine and handled by the
	 *			{@link cookxml.core.interfaces.ExceptionHandler}.
	 */
	public void setAttribute (String ns, String tag, String attrNS, String attr, Object obj, Object value, DecodeEngine decodeEngine) throws Exception;
}
