/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.interfaces;

import cookxml.core.DecodeEngine;


/**
 * This interface is used to intercept the string values obtained in the xml document.
 * The primary purpose is to allow locale based text to be set.  Although it is probably
 * a better idea to use entity resolver instead, using StringHook is simpler.
 *
 * @author Heng Yuan
 * @version $Id: StringHook.java 218 2007-06-06 06:10:10Z coconut $
 * @since CookXml 1.0
 */
public interface StringHook
{
	/**
	 * this function is used to substitute a string specified in XML with a different string.
	 * The main purpose of this function is to allow locale based string setup.
	 * @param	tag
	 * 			the parent tag
	 * @param	obj
	 * 			the parent object
	 * @param	attr
	 * 			the attribute that this string is hooked to
	 * @param	value
	 * 			the string value to be translated
	 * @param	decodeEngine
	 * 			the decodeEngine being used
	 * @return	the substituted string or the original string.
	 */
	public String getTranslatedString (String tag, Object obj, String attr, String value, DecodeEngine decodeEngine);
}
