/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.interfaces;

/**
*  A tag library should contain creators, setters, adders, and converters.
 * Depending on the namespace, the appropriate function objects are lookedup.
 *
 * @author Heng Yuan
 * @version $Id: TagLibrary.java 218 2007-06-06 06:10:10Z coconut $
 * @since CookXml 3.0
 */
public interface TagLibrary
{
	/**
	 * Get the SpecialCreator for the TagLibrary.  This function is called only
	 * once per DecodeEngine instance.
	 * <p>
	 * Most TagLibrary implementations should simply return the parent tag library
	 * implementation if it does not handle it for sure.  TagLibrary implementations
	 * that pool several TagLibraries should pool multiple SpecialCreator instances
	 * into one.
	 *
	 * @return	the creator for the object creation.
	 */
	public SpecialCreator getSpecialCreator ();
	/**
	 * Get the Creator object factory associated with the namespace and tag.
	 *
	 * @param   tagNS
	 *          the namespace.
	 * @param   tag
	 *          the tag name.
	 * @return  the Creator object.
	 */
	public Creator getCreator (String tagNS, String tag);

	/**
	 * Get the Setter delegate associated with the namespace and tag.
	 *
	 * @param   tagNS
	 *          the namespace.
	 * @param   tag
	 *          the tag name.
	 * @param	attrNS
	 *			the attribute namespace.
	 * @param   attr
	 *          the attribute name @return  the Setter delegate.
	 */
	public Setter getSetter (String tagNS, String tag, String attrNS, String attr);

	/**
	 * Get the Adder delegate associated with the namespace and tag.
	 *
	 * @param   tagNS
	 *          the tag namespace.
	 * @param   tag
	 *          the tag name.
	 * @return  the Adder delegate.
	 */
	public Adder getAdder (String tagNS, String tag);

	/**
	 * Get the Converter that converts a string attribute value into the target class.
	 *
	 * @param   attrNS
	 *          the attribute namespace.
	 * @param   targetClass
	 *          the target class type.
	 * @return  the Converter delegate.
	 */
	public Converter getConverter (String attrNS, Class targetClass);
}
