/*
 * (c) Copyright 2005 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.interfaces;

import cookxml.core.DecodeEngine;
import cookxml.core.exception.VarLookupException;

/**
 * This is a general interface for getting/setting object variables
 *
 * @author Heng Yuan
 * @version $Id: VarLookup.java 218 2007-06-06 06:10:10Z coconut $
 * @since CookXml 2.0
 */
public interface VarLookup
{
	/**
	 * Get a variable by its name.
	 *
	 * @param	name
	 * 			the name of the variable
	 * @param	decodeEngine
	 * 			the DecodeEngine being used.
	 * @return	the value of the variable.
	 * @throws	cookxml.core.exception.VarLookupException
	 * 			in case of error.
	  */
	public Object getVariable (String name, DecodeEngine decodeEngine) throws VarLookupException;

	/**
	 * Set a variable by its name.
	 *
	 * @param	name
	 * 			the name of the variable
	 * @param	value
	 * 			the new value for the variable
	 * @param	decodeEngine
	 * 			the DecodeEngine being used.
	 * @throws	cookxml.core.exception.VarLookupException
	 * 			in case of error.
	 */
	public void setVariable (String name, Object value, DecodeEngine decodeEngine) throws VarLookupException;
}
