/*
 * (c) Copyright 2004 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package cookxml.core.stringhook;

import java.util.ResourceBundle;

import cookxml.core.DecodeEngine;
import cookxml.core.interfaces.StringHook;

/**
 * This StringHook class translate the string that starts with HOOK_CHAR (default to @)
 * using the resource bundle.  If the resource string was not found or the string
 * does not start with the HOOK_CHAR, it is returned as is.
 *
 * @author Heng Yuan
 * @version $Id: ResourceBundleStringHook.java 255 2007-06-10 07:08:13Z coconut $
 * @see cookxml.core.interfaces.StringHook
 * @since CookXml 1.0
 */
public class ResourceBundleStringHook implements StringHook
{
	public static String HOOK_CHAR = "@";

	private ResourceBundle m_bundle;

	public ResourceBundleStringHook (ResourceBundle bundle)
	{
		m_bundle = bundle;
	}

	public String getTranslatedString (String tag, Object obj, String attr, String value, DecodeEngine decodeEngine)
	{
		if (!value.startsWith (HOOK_CHAR))
			return value;
		try
		{
			String trans = m_bundle.getString (value.substring (1));
			if (trans == null)
				return value;
			return trans;
		}
		catch (Exception ex)
		{
		}
		return value;  //To change body of implemented methods use File | Settings | File Templates.
	}
}
