/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package examples.namespace;

import javax.swing.*;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import cookxml.core.CookXml;
import cookxml.core.adder.CallFunctionAdder;
import cookxml.core.creator.DefaultCreator;
import cookxml.core.exceptionhandler.StrictExceptionHandler;
import cookxml.core.setter.DefaultSetter;
import cookxml.core.taglibrary.MultiNSTagLibrary;
import cookxml.core.taglibrary.SingleNSTagLibrary;

/**
 * This class demonstrates the behavior of MultiNSTagLibrary.
 *
 * Test this example with<br>
 *  examples/namespace/xml/multins.xml<br>
 */
public class MultiNSTagLibraryExample
{
	private static SingleNSTagLibrary s_frameTagLibrary;
	private static MultiNSTagLibrary s_tagLibrary;

	static
	{
		s_frameTagLibrary = new SingleNSTagLibrary ();
		s_frameTagLibrary.setNameSpace ("http://cookxml.sf.net/examples/multins/");

		s_frameTagLibrary.setCreator ("frame", DefaultCreator.getCreator (JFrame.class));

		s_frameTagLibrary.setAdder ("frame", new CallFunctionAdder ("setJMenuBar", JFrame.class, JMenuBar.class));
		s_frameTagLibrary.setSetter (null, null, DefaultSetter.getInstance ());

		s_tagLibrary = new MultiNSTagLibrary ();

		// now add two tag libraries to the MultNSTagLibrary
		s_tagLibrary.addTagLibrary (s_frameTagLibrary.getNameSpace (), s_frameTagLibrary);
		SingleNSTagLibrary menubarTagLibrary = SingleNSTagLibraryExample.getTagLibrary ();
		s_tagLibrary.addTagLibrary (menubarTagLibrary.getNameSpace (), menubarTagLibrary);
	}

	public static void main (String[] args) throws Exception
	{
		if (args.length != 1)
		{
			System.out.println ("Please specify an XML.");
			return;
		}

		DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance ();
		factory.setNamespaceAware (true);
		DocumentBuilder builder = factory.newDocumentBuilder ();
		CookXml cx = new CookXml (builder, s_tagLibrary, (Object)null);
		// make it strict in handling exceptions
		cx.setExceptionHandler (StrictExceptionHandler.getInstance ());

		JFrame f = (JFrame)cx.xmlDecode (args[0]);
		f.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
		f.pack ();
		f.setLocationRelativeTo (null);
		f.setVisible (true);
	}
}
