package examples.namespace;

import javax.swing.*;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import cookxml.core.CookXml;
import cookxml.core.adder.DefaultAdder;
import cookxml.core.creator.DefaultCreator;
import cookxml.core.exceptionhandler.StrictExceptionHandler;
import cookxml.core.setter.DefaultSetter;
import cookxml.core.taglibrary.SingleNSTagLibrary;

/**
 * This class demonstrates the behavior of SingleNSTagLibrary.
 *
 * Test this example with<br>
 *  examples/namespace/xml/singlens.xml<br>
 *  examples/namespace/xml/singlens_nons.xml<br>
 *  examples/namespace/xml/singlens_partialns.xml<br>
 *  examples/namespace/xml/singlens_otherns.xml<br>
 * <p>
 * The first three should be processed okay, but the last one should give errors.
 */
public class SingleNSTagLibraryExample
{
	private static SingleNSTagLibrary s_tagLibrary;

	static
	{
		s_tagLibrary = new SingleNSTagLibrary ();
		s_tagLibrary.setNameSpace ("http://cookxml.sf.net/examples/singlens/");

		s_tagLibrary.setCreator ("menubar", DefaultCreator.getCreator (JMenuBar.class));
		s_tagLibrary.setCreator ("menu", DefaultCreator.getCreator (JMenu.class));
		s_tagLibrary.setCreator ("menuitem", DefaultCreator.getCreator (JMenuItem.class));

		s_tagLibrary.setAdder (null, DefaultAdder.getInstance ());
		s_tagLibrary.setSetter (null, null, DefaultSetter.getInstance ());
	}

	public static SingleNSTagLibrary getTagLibrary ()
	{
		return s_tagLibrary;
	}

	public static void main (String[] args) throws Exception
	{
		if (args.length != 1)
		{
			System.out.println ("Please specify an XML.");
			return;
		}

		DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance ();
		factory.setNamespaceAware (true);
		DocumentBuilder builder = factory.newDocumentBuilder ();
		CookXml cx = new CookXml (builder, s_tagLibrary, (Object)null);
		// make it strict in handling exceptions
		cx.setExceptionHandler (StrictExceptionHandler.getInstance ());
		JMenuBar menuBar = (JMenuBar)cx.xmlDecode (args[0]);

		JFrame f = new JFrame ("CookXml Example");
		f.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
		f.setJMenuBar (menuBar);
		f.pack ();
		f.setLocationRelativeTo (null);
		f.setVisible (true);
	}
}
