package examples.tutorial;

import javax.swing.*;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import cookxml.core.CookXml;
import cookxml.core.adder.DefaultAdder;
import cookxml.core.creator.DefaultCreator;
import cookxml.core.setter.DefaultSetter;
import cookxml.core.taglibrary.SingleNSTagLibrary;

public class Tutorial1
{
	private static SingleNSTagLibrary s_tagLibrary;

	static
	{
		// I normally put setters/adders next to their corresponding creators, but
		// for this tutorial purpose, I separate them into four steps instead.

		// step 1: Create a TagLibrary
		SingleNSTagLibrary tagLibrary = new SingleNSTagLibrary ();

		// step 2: Tag Creators
		tagLibrary.setCreator ("menubar", DefaultCreator.getCreator (JMenuBar.class));
		tagLibrary.setCreator ("menu", DefaultCreator.getCreator (JMenu.class));
		tagLibrary.setCreator ("menuitem", DefaultCreator.getCreator (JMenuItem.class));

		// step 3: Setters
		tagLibrary.setSetter ("menu", "text", DefaultSetter.getInstance ());
		tagLibrary.setSetter ("menuitem", "text", DefaultSetter.getInstance ());

		// step 4: Adders
		tagLibrary.setAdder ("menubar", DefaultAdder.getInstance ());
		tagLibrary.setAdder ("menu", DefaultAdder.getInstance ());

		s_tagLibrary = tagLibrary;
	}

	public static void main (String[] args)
	{
		JMenuBar menuBar;
		try
		{
			// the DocumentBuilder used to parse the XML Document
			DocumentBuilder builder = DocumentBuilderFactory.newInstance ().newDocumentBuilder ();
			CookXml cookXml = new CookXml (builder, s_tagLibrary, (Object)null);
			menuBar = (JMenuBar)cookXml.xmlDecode ("examples/tutorial/xml/menubar1.xml");
		}
		catch (Exception ex)
		{
			ex.printStackTrace ();
			return;
		}
		JFrame f = new JFrame ("CookXml Tutorial");
		f.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
		f.setJMenuBar (menuBar);
		f.pack ();
		f.setLocationRelativeTo (null);
		f.setVisible (true);
	}
}
