/*
 * (c) Copyright 2006 by Heng Yuan
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package examples.tutorial;

import javax.swing.*;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import cookxml.core.CookXml;
import cookxml.core.adder.DefaultAdder;
import cookxml.core.creator.DefaultCreator;
import cookxml.core.setter.DefaultSetter;
import cookxml.core.setter.DoNothingSetter;
import cookxml.core.taglibrary.SingleNSTagLibrary;

public class Tutorial4
{
	private static SingleNSTagLibrary s_tagLibrary;

	static
	{
		// I normally put setters/adders next to their corresponding creators, but
		// for this tutorial purpose, I separate them into four steps instead.

		// Create a TagLibrary
		SingleNSTagLibrary tagLibrary = new SingleNSTagLibrary ();

		// setup default setter/adder
		tagLibrary.setSetter (null, null, DefaultSetter.getInstance ());
		tagLibrary.setAdder (null, DefaultAdder.getInstance ());

		// Tag Creators
		tagLibrary.setCreator ("menubar", DefaultCreator.getCreator (JMenuBar.class));
		tagLibrary.setCreator ("menu", DefaultCreator.getCreator (JMenu.class));
		tagLibrary.setCreator ("menuitem", DefaultCreator.getCreator (JMenuItem.class));

		// Tutorial 2: Converter
		tagLibrary.setConverter (KeyStroke.class, new KeyStrokeConverter ());

		// Tutorial 3
		// Use alignment setter to set the horizontal alignment of the label text in the menu item
		tagLibrary.setSetter ("menuitem", "horizontalalignment", new AlignmentSetter ());

		// Tutorial 4:
		// Add the Icon Creator
		tagLibrary.setCreator ("icon", new IconCreator ());
		tagLibrary.setSetter ("icon", "ui", DoNothingSetter.getInstance ());
		// Add the Adder for menuitem
		tagLibrary.setAdder ("menuitem", new MenuItemAdder ());

		s_tagLibrary = tagLibrary;
	}

	public static void main (String[] args)
	{
		JMenuBar menuBar;
		try
		{
			// the DocumentBuilder used to parse the XML Document
			DocumentBuilder builder = DocumentBuilderFactory.newInstance ().newDocumentBuilder ();
			CookXml cookXml = new CookXml (builder, s_tagLibrary, (Object)null);
			menuBar = (JMenuBar)cookXml.xmlDecode ("examples/tutorial/xml/menubar4.xml");
		}
		catch (Exception ex)
		{
			ex.printStackTrace ();
			return;
		}
		JFrame f = new JFrame ("CookXml Tutorial");
		f.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
		f.setJMenuBar (menuBar);
		f.pack ();
		f.setLocationRelativeTo (null);
		f.setVisible (true);
	}
}
